from onix.book.v3_0.short.book_3_0_short import (
    Onixmessage,
    OnixmessageRefname,
    OnixmessageShortname,
    A001,
    A001Refname,
    A001Shortname,
    A002,
    A002Refname,
    A002Shortname,
    A194,
    A194Refname,
    A194Shortname,
    A197,
    A197Refname,
    A197Shortname,
    A199,
    A199Refname,
    A199Shortname,
    Addressee,
    AddresseeRefname,
    AddresseeShortname,
    Addresseeidentifier,
    AddresseeidentifierRefname,
    AddresseeidentifierShortname,
    Agentidentifier,
    AgentidentifierRefname,
    AgentidentifierShortname,
    Alternativename,
    AlternativenameRefname,
    AlternativenameShortname,
    Ancillarycontent,
    AncillarycontentRefname,
    AncillarycontentShortname,
    Audience,
    AudienceRefname,
    AudienceShortname,
    Audiencerange,
    AudiencerangeRefname,
    AudiencerangeShortname,
    Avitem,
    AvitemRefname,
    AvitemShortname,
    Avitemidentifier,
    AvitemidentifierRefname,
    AvitemidentifierShortname,
    B012,
    B012Refname,
    B012Shortname,
    B014,
    B014Refname,
    B014Shortname,
    B020,
    B020Refname,
    B020Shortname,
    B029,
    B029Refname,
    B029Shortname,
    B030,
    B030Refname,
    B030Shortname,
    B031,
    B031Refname,
    B031Shortname,
    B034,
    B034Refname,
    B034Shortname,
    B035,
    B035Refname,
    B035Shortname,
    B036,
    B036Refname,
    B036Shortname,
    B037,
    B037Refname,
    B037Shortname,
    B038,
    B038Refname,
    B038Shortname,
    B039,
    B039Refname,
    B039Shortname,
    B040,
    B040Refname,
    B040Shortname,
    B041,
    B041Refname,
    B041Shortname,
    B042,
    B042Refname,
    B042Shortname,
    B043,
    B043Refname,
    B043Shortname,
    B044,
    B044Refname,
    B044Shortname,
    B045,
    B045Refname,
    B045Shortname,
    B046,
    B046Refname,
    B046Shortname,
    B047,
    B047Refname,
    B047Shortname,
    B048,
    B048Refname,
    B048Shortname,
    B049,
    B049Refname,
    B049Shortname,
    B051,
    B051Refname,
    B051Shortname,
    B052,
    B052Refname,
    B052Shortname,
    B053,
    B053Refname,
    B053Shortname,
    B054,
    B054Refname,
    B054Shortname,
    B055,
    B055Refname,
    B055Shortname,
    B057,
    B057Refname,
    B057Shortname,
    B058,
    B058Refname,
    B058Shortname,
    B061,
    B061Refname,
    B061Shortname,
    B062,
    B062Refname,
    B062Shortname,
    B063,
    B063Refname,
    B063Shortname,
    B067,
    B067Refname,
    B067Shortname,
    B068,
    B068Refname,
    B068Shortname,
    B069,
    B069Refname,
    B069Shortname,
    B070,
    B070Refname,
    B070Shortname,
    B073,
    B073Refname,
    B073Shortname,
    B074,
    B074Refname,
    B074Shortname,
    B075,
    B075Refname,
    B075Shortname,
    B076,
    B076Refname,
    B076Shortname,
    B077,
    B077Refname,
    B077Shortname,
    B078,
    B078Refname,
    B078Shortname,
    B079,
    B079Refname,
    B079Shortname,
    B081,
    B081Refname,
    B081Shortname,
    B083,
    B083Refname,
    B083Shortname,
    B087,
    B087Refname,
    B087Shortname,
    B089,
    B089Refname,
    B089Shortname,
    B125,
    B125Refname,
    B125Shortname,
    B171,
    B171Refname,
    B171Shortname,
    B201,
    B201Refname,
    B201Shortname,
    B202,
    B202Refname,
    B202Shortname,
    B203,
    B203Refname,
    B203Shortname,
    B204,
    B204Refname,
    B204Shortname,
    B205,
    B205Refname,
    B205Shortname,
    B206,
    B206Refname,
    B206Shortname,
    B207,
    B207Refname,
    B207Shortname,
    B209,
    B209Refname,
    B209Shortname,
    B217,
    B217Refname,
    B217Shortname,
    B218,
    B218Refname,
    B218Shortname,
    B219,
    B219Refname,
    B219Shortname,
    B220,
    B220Refname,
    B220Shortname,
    B221,
    B221Refname,
    B221Shortname,
    B225,
    B225Refname,
    B225Shortname,
    B233,
    B233Refname,
    B233Shortname,
    B244,
    B244Refname,
    B244Shortname,
    B247,
    B247Refname,
    B247Shortname,
    B248,
    B248Refname,
    B248Shortname,
    B249,
    B249Refname,
    B249Shortname,
    B251,
    B251Refname,
    B251Shortname,
    B252,
    B252Refname,
    B252Shortname,
    B253,
    B253Refname,
    B253Shortname,
    B257,
    B257Refname,
    B257Shortname,
    B274,
    B274Refname,
    B274Shortname,
    B275,
    B275Refname,
    B275Shortname,
    B284,
    B284Refname,
    B284Shortname,
    B285,
    B285Refname,
    B285Shortname,
    B286,
    B286Refname,
    B286Shortname,
    B287,
    B287Refname,
    B287Shortname,
    B288,
    B288Refname,
    B288Shortname,
    B289,
    B289Refname,
    B289Shortname,
    B290,
    B290Refname,
    B290Shortname,
    B291,
    B291Refname,
    B291Shortname,
    B294,
    B294Refname,
    B294Shortname,
    B295,
    B295Refname,
    B295Shortname,
    B306,
    B306Refname,
    B306Shortname,
    B324,
    B324Refname,
    B324Shortname,
    B325,
    B325Refname,
    B325Shortname,
    B333,
    B333Refname,
    B333Shortname,
    B334,
    B334Refname,
    B334Shortname,
    B335,
    B335Refname,
    B335Shortname,
    B336,
    B336Refname,
    B336Shortname,
    B337,
    B337Refname,
    B337Shortname,
    B341,
    B341Refname,
    B341Shortname,
    B342,
    B342Refname,
    B342Shortname,
    B352,
    B352Refname,
    B352Shortname,
    B353,
    B353Refname,
    B353Shortname,
    B354,
    B354Refname,
    B354Shortname,
    B355,
    B355Refname,
    B355Shortname,
    B356,
    B356Refname,
    B356Shortname,
    B357,
    B357Refname,
    B357Shortname,
    B358,
    B358Refname,
    B358Shortname,
    B359,
    B359Refname,
    B359Shortname,
    B360,
    B360Refname,
    B360Shortname,
    B367,
    B367Refname,
    B367Shortname,
    B368,
    B368Refname,
    B368Shortname,
    B369,
    B369Refname,
    B369Shortname,
    B370,
    B370Refname,
    B370Shortname,
    B374,
    B374Refname,
    B374Shortname,
    B376,
    B376Refname,
    B376Shortname,
    B381,
    B381Refname,
    B381Shortname,
    B382,
    B382Refname,
    B382Shortname,
    B384,
    B384Refname,
    B384Shortname,
    B385,
    B385Refname,
    B385Shortname,
    B389,
    B389Refname,
    B389Shortname,
    B391,
    B391Refname,
    B391Shortname,
    B392,
    B392Refname,
    B392Shortname,
    B393,
    B393Refname,
    B393Shortname,
    B394,
    B394Refname,
    B394Shortname,
    B395,
    B395Refname,
    B395Shortname,
    B398,
    B398Refname,
    B398Shortname,
    Barcode,
    BarcodeRefname,
    BarcodeShortname,
    Batchbonus,
    BatchbonusRefname,
    BatchbonusShortname,
    Bible,
    BibleRefname,
    BibleShortname,
    Bodymanifest,
    BodymanifestRefname,
    BodymanifestShortname,
    Bodyresource,
    BodyresourceRefname,
    BodyresourceShortname,
    C094,
    C094Refname,
    C094Shortname,
    C095,
    C095Refname,
    C095Shortname,
    Citedcontent,
    CitedcontentRefname,
    CitedcontentShortname,
    Collateraldetail,
    CollateraldetailRefname,
    CollateraldetailShortname,
    Collection,
    CollectionRefname,
    CollectionShortname,
    Collectionidentifier,
    CollectionidentifierRefname,
    CollectionidentifierShortname,
    Collectionsequence,
    CollectionsequenceRefname,
    CollectionsequenceShortname,
    Comparisonproductprice,
    ComparisonproductpriceRefname,
    ComparisonproductpriceShortname,
    Complexity,
    ComplexityRefname,
    ComplexityShortname,
    Conference,
    ConferenceRefname,
    ConferenceShortname,
    Conferencesponsor,
    ConferencesponsorRefname,
    ConferencesponsorShortname,
    Conferencesponsoridentifier,
    ConferencesponsoridentifierRefname,
    ConferencesponsoridentifierShortname,
    Contentdate,
    ContentdateRefname,
    ContentdateShortname,
    Contentdetail,
    ContentdetailRefname,
    ContentdetailShortname,
    Contentitem,
    ContentitemRefname,
    ContentitemShortname,
    Contributor,
    ContributorRefname,
    ContributorShortname,
    Contributordate,
    ContributordateRefname,
    ContributordateShortname,
    Contributorplace,
    ContributorplaceRefname,
    ContributorplaceShortname,
    Contributorreference,
    ContributorreferenceRefname,
    ContributorreferenceShortname,
    Copyrightowner,
    CopyrightownerRefname,
    CopyrightownerShortname,
    Copyrightowneridentifier,
    CopyrightowneridentifierRefname,
    CopyrightowneridentifierShortname,
    Copyrightstatement,
    CopyrightstatementRefname,
    CopyrightstatementShortname,
    Covermanifest,
    CovermanifestRefname,
    CovermanifestShortname,
    Coverresource,
    CoverresourceRefname,
    CoverresourceShortname,
    D104,
    D104Refname,
    D104Shortname,
    D107,
    D107Refname,
    D107Shortname,
    Descriptivedetail,
    DescriptivedetailRefname,
    DescriptivedetailShortname,
    Discount,
    DiscountRefname,
    DiscountShortname,
    Discountcoded,
    DiscountcodedRefname,
    DiscountcodedShortname,
    Epublicense,
    EpublicenseRefname,
    EpublicenseShortname,
    Epublicenseexpression,
    EpublicenseexpressionRefname,
    EpublicenseexpressionShortname,
    Epubusageconstraint,
    EpubusageconstraintRefname,
    EpubusageconstraintShortname,
    Epubusagelimit,
    EpubusagelimitRefname,
    EpubusagelimitShortname,
    Event,
    EventRefname,
    EventShortname,
    Eventidentifier,
    EventidentifierRefname,
    EventidentifierShortname,
    Eventoccurrence,
    EventoccurrenceRefname,
    EventoccurrenceShortname,
    Eventsponsor,
    EventsponsorRefname,
    EventsponsorShortname,
    Eventsponsoridentifier,
    EventsponsoridentifierRefname,
    EventsponsoridentifierShortname,
    Extent,
    ExtentRefname,
    ExtentShortname,
    Funding,
    FundingRefname,
    FundingShortname,
    Fundingidentifier,
    FundingidentifierRefname,
    FundingidentifierShortname,
    G126,
    G126Refname,
    G126Shortname,
    G127,
    G127Refname,
    G127Shortname,
    G128,
    G128Refname,
    G128Shortname,
    G129,
    G129Refname,
    G129Shortname,
    G343,
    G343Refname,
    G343Shortname,
    Header,
    HeaderRefname,
    HeaderShortname,
    Imprint,
    ImprintRefname,
    ImprintShortname,
    Imprintidentifier,
    ImprintidentifierRefname,
    ImprintidentifierShortname,
    Insertmanifest,
    InsertmanifestRefname,
    InsertmanifestShortname,
    Insertpoint,
    InsertpointRefname,
    InsertpointShortname,
    Insertresource,
    InsertresourceRefname,
    InsertresourceShortname,
    J137,
    J137Refname,
    J137Shortname,
    J144,
    J144Refname,
    J144Shortname,
    J145,
    J145Refname,
    J145Shortname,
    J151,
    J151Refname,
    J151Shortname,
    J152,
    J152Refname,
    J152Shortname,
    J192,
    J192Refname,
    J192Shortname,
    J239,
    J239Refname,
    J239Shortname,
    J260,
    J260Refname,
    J260Shortname,
    J261,
    J261Refname,
    J261Shortname,
    J262,
    J262Refname,
    J262Shortname,
    J263,
    J263Refname,
    J263Shortname,
    J264,
    J264Refname,
    J264Shortname,
    J265,
    J265Refname,
    J265Shortname,
    J266,
    J266Refname,
    J266Shortname,
    J267,
    J267Refname,
    J267Shortname,
    J268,
    J268Refname,
    J268Shortname,
    J269,
    J269Refname,
    J269Shortname,
    J270,
    J270Refname,
    J270Shortname,
    J271,
    J271Refname,
    J271Shortname,
    J272,
    J272Refname,
    J272Shortname,
    J292,
    J292Refname,
    J292Shortname,
    J293,
    J293Refname,
    J293Shortname,
    J296,
    J296Refname,
    J296Shortname,
    J297,
    J297Refname,
    J297Shortname,
    J302,
    J302Refname,
    J302Shortname,
    J345,
    J345Refname,
    J345Shortname,
    J349,
    J349Refname,
    J349Shortname,
    J350,
    J350Refname,
    J350Shortname,
    J351,
    J351Refname,
    J351Shortname,
    J363,
    J363Refname,
    J363Shortname,
    J364,
    J364Refname,
    J364Shortname,
    J365,
    J365Refname,
    J365Shortname,
    J366,
    J366Refname,
    J366Shortname,
    J375,
    J375Refname,
    J375Shortname,
    J377,
    J377Refname,
    J377Shortname,
    J378,
    J378Refname,
    J378Shortname,
    J396,
    J396Refname,
    J396Shortname,
    J400,
    J400Refname,
    J400Shortname,
    J401,
    J401Refname,
    J401Shortname,
    J402,
    J402Refname,
    J402Shortname,
    J407,
    J407Refname,
    J407Shortname,
    J408,
    J408Refname,
    J408Shortname,
    K165,
    K165Refname,
    K165Shortname,
    K166,
    K166Refname,
    K166Shortname,
    K167,
    K167Refname,
    K167Shortname,
    K168,
    K168Refname,
    K168Shortname,
    K169,
    K169Refname,
    K169Shortname,
    K309,
    K309Refname,
    K309Shortname,
    Language,
    LanguageRefname,
    LanguageShortname,
    Locationidentifier,
    LocationidentifierRefname,
    LocationidentifierShortname,
    M180,
    M180Refname,
    M180Shortname,
    M181,
    M181Refname,
    M181Shortname,
    M183,
    M183Refname,
    M183Shortname,
    M184,
    M184Refname,
    M184Shortname,
    M186,
    M186Refname,
    M186Shortname,
    M379,
    M379Refname,
    M379Shortname,
    M380,
    M380Refname,
    M380Shortname,
    Market,
    MarketRefname,
    MarketShortname,
    Marketdate,
    MarketdateRefname,
    MarketdateShortname,
    Marketpublishingdetail,
    MarketpublishingdetailRefname,
    MarketpublishingdetailShortname,
    Measure,
    MeasureRefname,
    MeasureShortname,
    N339,
    N339Refname,
    N339Shortname,
    N386,
    N386Refname,
    N386Shortname,
    Nameassubject,
    NameassubjectRefname,
    NameassubjectShortname,
    Nameidentifier,
    NameidentifierRefname,
    NameidentifierShortname,
    Newsupplier,
    NewsupplierRefname,
    NewsupplierShortname,
    Occurrencedate,
    OccurrencedateRefname,
    OccurrencedateShortname,
    Onorderdetail,
    OnorderdetailRefname,
    OnorderdetailShortname,
    Pagerun,
    PagerunRefname,
    PagerunShortname,
    Price,
    PriceRefname,
    PriceShortname,
    Pricecoded,
    PricecodedRefname,
    PricecodedShortname,
    Pricecondition,
    PriceconditionRefname,
    PriceconditionShortname,
    Priceconditionquantity,
    PriceconditionquantityRefname,
    PriceconditionquantityShortname,
    Priceconstraint,
    PriceconstraintRefname,
    PriceconstraintShortname,
    Priceconstraintlimit,
    PriceconstraintlimitRefname,
    PriceconstraintlimitShortname,
    Pricedate,
    PricedateRefname,
    PricedateShortname,
    Priceidentifier,
    PriceidentifierRefname,
    PriceidentifierShortname,
    Prize,
    PrizeRefname,
    PrizeShortname,
    Product,
    ProductRefname,
    ProductShortname,
    Productclassification,
    ProductclassificationRefname,
    ProductclassificationShortname,
    Productcontact,
    ProductcontactRefname,
    ProductcontactShortname,
    Productcontactidentifier,
    ProductcontactidentifierRefname,
    ProductcontactidentifierShortname,
    Productformfeature,
    ProductformfeatureRefname,
    ProductformfeatureShortname,
    Productidentifier,
    ProductidentifierRefname,
    ProductidentifierShortname,
    Productiondetail,
    ProductiondetailRefname,
    ProductiondetailShortname,
    Productionmanifest,
    ProductionmanifestRefname,
    ProductionmanifestShortname,
    Productpart,
    ProductpartRefname,
    ProductpartShortname,
    Productsupply,
    ProductsupplyRefname,
    ProductsupplyShortname,
    Professionalaffiliation,
    ProfessionalaffiliationRefname,
    ProfessionalaffiliationShortname,
    Promotionalevent,
    PromotionaleventRefname,
    PromotionaleventShortname,
    Promotiondetail,
    PromotiondetailRefname,
    PromotiondetailShortname,
    Publisher,
    PublisherRefname,
    PublisherShortname,
    Publisheridentifier,
    PublisheridentifierRefname,
    PublisheridentifierShortname,
    Publisherrepresentative,
    PublisherrepresentativeRefname,
    PublisherrepresentativeShortname,
    Publishingdate,
    PublishingdateRefname,
    PublishingdateShortname,
    Publishingdetail,
    PublishingdetailRefname,
    PublishingdetailShortname,
    Recordsourceidentifier,
    RecordsourceidentifierRefname,
    RecordsourceidentifierShortname,
    Reissue,
    ReissueRefname,
    ReissueShortname,
    Relatedmaterial,
    RelatedmaterialRefname,
    RelatedmaterialShortname,
    Relatedproduct,
    RelatedproductRefname,
    RelatedproductShortname,
    Relatedwork,
    RelatedworkRefname,
    RelatedworkShortname,
    ReleaseAttributeRelease,
    Religioustext,
    ReligioustextRefname,
    ReligioustextShortname,
    Religioustextfeature,
    ReligioustextfeatureRefname,
    ReligioustextfeatureShortname,
    Resourcefeature,
    ResourcefeatureRefname,
    ResourcefeatureShortname,
    Resourcefiledate,
    ResourcefiledateRefname,
    ResourcefiledateShortname,
    Resourcefilefeature,
    ResourcefilefeatureRefname,
    ResourcefilefeatureShortname,
    Resourceidentifier,
    ResourceidentifierRefname,
    ResourceidentifierShortname,
    Resourceversion,
    ResourceversionRefname,
    ResourceversionShortname,
    Resourceversionfeature,
    ResourceversionfeatureRefname,
    ResourceversionfeatureShortname,
    Returnsconditions,
    ReturnsconditionsRefname,
    ReturnsconditionsShortname,
    Reviewrating,
    ReviewratingRefname,
    ReviewratingShortname,
    Salesoutlet,
    SalesoutletRefname,
    SalesoutletShortname,
    Salesoutletidentifier,
    SalesoutletidentifierRefname,
    SalesoutletidentifierShortname,
    Salesrestriction,
    SalesrestrictionRefname,
    SalesrestrictionShortname,
    Salesrights,
    SalesrightsRefname,
    SalesrightsShortname,
    Sender,
    SenderRefname,
    SenderShortname,
    Senderidentifier,
    SenderidentifierRefname,
    SenderidentifierShortname,
    Specificationbundlename,
    SpecificationbundlenameRefname,
    SpecificationbundlenameShortname,
    Specificationfeature,
    SpecificationfeatureRefname,
    SpecificationfeatureShortname,
    Stock,
    StockRefname,
    StockShortname,
    Stockquantitycoded,
    StockquantitycodedRefname,
    StockquantitycodedShortname,
    Subject,
    SubjectRefname,
    SubjectShortname,
    Subjectdate,
    SubjectdateRefname,
    SubjectdateShortname,
    Supplementmanifest,
    SupplementmanifestRefname,
    SupplementmanifestShortname,
    Supplier,
    SupplierRefname,
    SupplierShortname,
    Supplieridentifier,
    SupplieridentifierRefname,
    SupplieridentifierShortname,
    Supplierowncoding,
    SupplierowncodingRefname,
    SupplierowncodingShortname,
    Supplycontact,
    SupplycontactRefname,
    SupplycontactShortname,
    Supplycontactidentifier,
    SupplycontactidentifierRefname,
    SupplycontactidentifierShortname,
    Supplydate,
    SupplydateRefname,
    SupplydateShortname,
    Supplydetail,
    SupplydetailRefname,
    SupplydetailShortname,
    Supportingresource,
    SupportingresourceRefname,
    SupportingresourceShortname,
    Tax,
    TaxRefname,
    TaxShortname,
    Territory,
    TerritoryRefname,
    TerritoryShortname,
    Textcontent,
    TextcontentRefname,
    TextcontentShortname,
    Textitem,
    TextitemRefname,
    TextitemShortname,
    Textitemidentifier,
    TextitemidentifierRefname,
    TextitemidentifierShortname,
    Timerun,
    TimerunRefname,
    TimerunShortname,
    Titledetail,
    TitledetailRefname,
    TitledetailShortname,
    Titleelement,
    TitleelementRefname,
    TitleelementShortname,
    Velocity,
    VelocityRefname,
    VelocityShortname,
    Website,
    WebsiteRefname,
    WebsiteShortname,
    Workidentifier,
    WorkidentifierRefname,
    WorkidentifierShortname,
    X298,
    X298Refname,
    X298Shortname,
    X299,
    X299Refname,
    X299Shortname,
    X300,
    X300Refname,
    X300Shortname,
    X301,
    X301Refname,
    X301Shortname,
    X307,
    X307Refname,
    X307Shortname,
    X310,
    X310Refname,
    X310Shortname,
    X311,
    X311Refname,
    X311Shortname,
    X312,
    X312Refname,
    X312Shortname,
    X313,
    X313Refname,
    X313Shortname,
    X314,
    X314Refname,
    X314Shortname,
    X315,
    X315Refname,
    X315Shortname,
    X316,
    X316Refname,
    X316Shortname,
    X317,
    X317Refname,
    X317Shortname,
    X318,
    X318Refname,
    X318Shortname,
    X319,
    X319Refname,
    X319Shortname,
    X320,
    X320Refname,
    X320Shortname,
    X321,
    X321Refname,
    X321Shortname,
    X322,
    X322Refname,
    X322Shortname,
    X323,
    X323Refname,
    X323Shortname,
    X329,
    X329Refname,
    X329Shortname,
    X330,
    X330Refname,
    X330Shortname,
    X344,
    X344Refname,
    X344Shortname,
    X406,
    X406Refname,
    X406Shortname,
    X409,
    X409Refname,
    X409Shortname,
    X410,
    X410Refname,
    X410Shortname,
    X411,
    X411Refname,
    X411Shortname,
    X412,
    X412Refname,
    X412Shortname,
    X413,
    X413Refname,
    X413Shortname,
    X414,
    X414Refname,
    X414Shortname,
    X415,
    X415Refname,
    X415Shortname,
    X416,
    X416Refname,
    X416Shortname,
    X417,
    X417Refname,
    X417Shortname,
    X418,
    X418Refname,
    X418Shortname,
    X419,
    X419Refname,
    X419Shortname,
    X420,
    X420Refname,
    X420Shortname,
    X421,
    X421Refname,
    X421Shortname,
    X422,
    X422Refname,
    X422Shortname,
    X423,
    X423Refname,
    X423Shortname,
    X424,
    X424Refname,
    X424Shortname,
    X425,
    X425Refname,
    X425Shortname,
    X426,
    X426Refname,
    X426Shortname,
    X427,
    X427Refname,
    X427Shortname,
    X428,
    X428Refname,
    X428Shortname,
    X429,
    X429Refname,
    X429Shortname,
    X430,
    X430Refname,
    X430Shortname,
    X431,
    X431Refname,
    X431Shortname,
    X432,
    X432Refname,
    X432Shortname,
    X433,
    X433Refname,
    X433Shortname,
    X434,
    X434Refname,
    X434Shortname,
    X435,
    X435Refname,
    X435Shortname,
    X436,
    X436Refname,
    X436Shortname,
    X437,
    X437Refname,
    X437Shortname,
    X438,
    X438Refname,
    X438Shortname,
    X439,
    X439Refname,
    X439Shortname,
    X440,
    X440Refname,
    X440Shortname,
    X441,
    X441Refname,
    X441Shortname,
    X442,
    X442Refname,
    X442Shortname,
    X443,
    X443Refname,
    X443Shortname,
    X445,
    X445Refname,
    X445Shortname,
    X446,
    X446Refname,
    X446Shortname,
    X447,
    X447Refname,
    X447Shortname,
    X448,
    X448Refname,
    X448Shortname,
    X449,
    X449Refname,
    X449Shortname,
    X450,
    X450Refname,
    X450Shortname,
    X451,
    X451Refname,
    X451Shortname,
    X452,
    X452Refname,
    X452Shortname,
    X453,
    X453Refname,
    X453Shortname,
    X454,
    X454Refname,
    X454Shortname,
    X455,
    X455Refname,
    X455Shortname,
    X456,
    X456Refname,
    X456Shortname,
    X457,
    X457Refname,
    X457Shortname,
    X458,
    X458Refname,
    X458Shortname,
    X459,
    X459Refname,
    X459Shortname,
    X460,
    X460Refname,
    X460Shortname,
    X461,
    X461Refname,
    X461Shortname,
    X462,
    X462Refname,
    X462Shortname,
    X463,
    X463Refname,
    X463Shortname,
    X464,
    X464Refname,
    X464Shortname,
    X465,
    X465Refname,
    X465Shortname,
    X466,
    X466Refname,
    X466Shortname,
    X467,
    X467Refname,
    X467Shortname,
    X468,
    X468Refname,
    X468Shortname,
    X469,
    X469Refname,
    X469Shortname,
    X470,
    X470Refname,
    X470Shortname,
    X471,
    X471Refname,
    X471Shortname,
    X472,
    X472Refname,
    X472Shortname,
    X473,
    X473Refname,
    X473Shortname,
    X474,
    X474Refname,
    X474Shortname,
    X475,
    X475Refname,
    X475Shortname,
    X476,
    X476Refname,
    X476Shortname,
    X477,
    X477Refname,
    X477Shortname,
    X478,
    X478Refname,
    X478Shortname,
    X479,
    X479Refname,
    X479Shortname,
    X480,
    X480Refname,
    X480Shortname,
    X481,
    X481Refname,
    X481Shortname,
    X482,
    X482Refname,
    X482Shortname,
    X483,
    X483Refname,
    X483Shortname,
    X484,
    X484Refname,
    X484Shortname,
    X501,
    X501Refname,
    X501Shortname,
    X502,
    X502Refname,
    X502Shortname,
    X503,
    X503Refname,
    X503Shortname,
    X504,
    X504Refname,
    X504Shortname,
    X505,
    X505Refname,
    X505Shortname,
    X506,
    X506Refname,
    X506Shortname,
    X507,
    X507Refname,
    X507Shortname,
    X508,
    X508Refname,
    X508Shortname,
    X509,
    X509Refname,
    X509Shortname,
    X510,
    X510Refname,
    X510Shortname,
    X511,
    X511Refname,
    X511Shortname,
    X512,
    X512Refname,
    X512Shortname,
    X513,
    X513Refname,
    X513Shortname,
    X514,
    X514Refname,
    X514Shortname,
    X515,
    X515Refname,
    X515Shortname,
    X516,
    X516Refname,
    X516Shortname,
    X517,
    X517Refname,
    X517Shortname,
    X518,
    X518Refname,
    X518Shortname,
    X519,
    X519Refname,
    X519Shortname,
    X520,
    X520Refname,
    X520Shortname,
    X521,
    X521Refname,
    X521Shortname,
    X522,
    X522Refname,
    X522Shortname,
    X523,
    X523Refname,
    X523Shortname,
    X524,
    X524Refname,
    X524Shortname,
    X525,
    X525Refname,
    X525Shortname,
    X526,
    X526Refname,
    X526Shortname,
    X527,
    X527Refname,
    X527Shortname,
    X528,
    X528Refname,
    X528Shortname,
    X529,
    X529Refname,
    X529Shortname,
    X530,
    X530Refname,
    X530Shortname,
    X531,
    X531Refname,
    X531Shortname,
    X532,
    X532Refname,
    X532Shortname,
    X533,
    X533Refname,
    X533Shortname,
    X534,
    X534Refname,
    X534Shortname,
    X535,
    X535Refname,
    X535Shortname,
    X536,
    X536Refname,
    X536Shortname,
    X537,
    X537Refname,
    X537Shortname,
    X538,
    X538Refname,
    X538Shortname,
    X539,
    X539Refname,
    X539Shortname,
    X540,
    X540Refname,
    X540Shortname,
    X541,
    X541Refname,
    X541Shortname,
    X542,
    X542Refname,
    X542Shortname,
    X543,
    X543Refname,
    X543Shortname,
    X544,
    X544Refname,
    X544Shortname,
    X545,
    X545Refname,
    X545Shortname,
    X546,
    X546Refname,
    X546Shortname,
    X547,
    X547Refname,
    X547Shortname,
    X548,
    X548Refname,
    X548Shortname,
    X549,
    X549Refname,
    X549Shortname,
    X550,
    X550Refname,
    X550Shortname,
    X551,
    X551Refname,
    X551Shortname,
    X552,
    X552Refname,
    X552Shortname,
    X553,
    X553Refname,
    X553Shortname,
    X554,
    X554Refname,
    X554Shortname,
    X555,
    X555Refname,
    X555Shortname,
    X556,
    X556Refname,
    X556Shortname,
    X557,
    X557Refname,
    X557Shortname,
    X558,
    X558Refname,
    X558Shortname,
    X559,
    X559Refname,
    X559Shortname,
    X560,
    X560Refname,
    X560Shortname,
    X561,
    X561Refname,
    X561Shortname,
    X562,
    X562Refname,
    X562Shortname,
    X563,
    X563Refname,
    X563Shortname,
    X564,
    X564Refname,
    X564Shortname,
    X565,
    X565Refname,
    X565Shortname,
    X566,
    X566Refname,
    X566Shortname,
    X567,
    X567Refname,
    X567Shortname,
    X568,
    X568Refname,
    X568Shortname,
    X569,
    X569Refname,
    X569Shortname,
    X570,
    X570Refname,
    X570Shortname,
    X571,
    X571Refname,
    X571Shortname,
    X572,
    X572Refname,
    X572Shortname,
    X573,
    X573Refname,
    X573Shortname,
    X574,
    X574Refname,
    X574Shortname,
    X575,
    X575Refname,
    X575Shortname,
    X576,
    X576Refname,
    X576Shortname,
    X577,
    X577Refname,
    X577Shortname,
    X578,
    X578Refname,
    X578Shortname,
    X579,
    X579Refname,
    X579Shortname,
)
from onix.book.v3_0.short.onix_book_product_code_lists import (
    List1,
    List100,
    List102,
    List12,
    List121,
    List13,
    List14,
    List141,
    List142,
    List144,
    List145,
    List146,
    List147,
    List148,
    List149,
    List15,
    List150,
    List151,
    List152,
    List153,
    List154,
    List155,
    List156,
    List157,
    List158,
    List159,
    List16,
    List160,
    List161,
    List162,
    List163,
    List164,
    List165,
    List166,
    List167,
    List168,
    List169,
    List17,
    List170,
    List171,
    List172,
    List173,
    List174,
    List175,
    List177,
    List179,
    List18,
    List19,
    List197,
    List198,
    List2,
    List20,
    List21,
    List215,
    List216,
    List217,
    List218,
    List219,
    List22,
    List228,
    List229,
    List23,
    List230,
    List239,
    List24,
    List240,
    List241,
    List244,
    List245,
    List246,
    List247,
    List248,
    List249,
    List25,
    List250,
    List252,
    List253,
    List254,
    List255,
    List27,
    List28,
    List29,
    List3,
    List30,
    List31,
    List32,
    List34,
    List41,
    List42,
    List43,
    List44,
    List45,
    List46,
    List48,
    List49,
    List5,
    List50,
    List51,
    List53,
    List55,
    List57,
    List58,
    List59,
    List60,
    List61,
    List62,
    List64,
    List65,
    List68,
    List69,
    List70,
    List71,
    List72,
    List73,
    List74,
    List79,
    List80,
    List81,
    List82,
    List83,
    List84,
    List85,
    List86,
    List87,
    List89,
    List9,
    List90,
    List91,
    List92,
    List93,
    List96,
    List97,
)
from onix.book.v3_0.short.onix_xhtml_subset import (
    Block,
    Flow,
    Inline,
    Scope,
    Shape,
    Tframe,
    Trules,
    A,
    AContent,
    Abbr,
    Acronym,
    Address,
    Area,
    AreaAttlistNohref,
    B,
    Bdo,
    BdoAttlistDir,
    Big,
    Blockquote,
    Br,
    Caption,
    CellhalignAlign,
    CellvalignValign,
    Cite,
    Code,
    Col,
    Colgroup,
    Dd,
    Dfn,
    Div,
    Dl,
    Dt,
    Em,
    H1,
    H2,
    H3,
    H4,
    H5,
    H6,
    Hr,
    I,
    I18NDir,
    Img,
    ImgAttlistIsmap,
    Kbd,
    Li,
    Map,
    Ol,
    P,
    Pre,
    PreContent,
    Q,
    Rb,
    Rbc,
    Rp,
    Rt,
    Rtc,
    Ruby,
    RubyContent,
    Samp,
    Small,
    Span,
    Strong,
    Sub,
    Sup,
    Table,
    Tbody,
    Td,
    Tfoot,
    Th,
    Thead,
    Tr,
    Tt,
    Ul,
    Var,
)

__all__ = [
    "Onixmessage",
    "OnixmessageRefname",
    "OnixmessageShortname",
    "A001",
    "A001Refname",
    "A001Shortname",
    "A002",
    "A002Refname",
    "A002Shortname",
    "A194",
    "A194Refname",
    "A194Shortname",
    "A197",
    "A197Refname",
    "A197Shortname",
    "A199",
    "A199Refname",
    "A199Shortname",
    "Addressee",
    "AddresseeRefname",
    "AddresseeShortname",
    "Addresseeidentifier",
    "AddresseeidentifierRefname",
    "AddresseeidentifierShortname",
    "Agentidentifier",
    "AgentidentifierRefname",
    "AgentidentifierShortname",
    "Alternativename",
    "AlternativenameRefname",
    "AlternativenameShortname",
    "Ancillarycontent",
    "AncillarycontentRefname",
    "AncillarycontentShortname",
    "Audience",
    "AudienceRefname",
    "AudienceShortname",
    "Audiencerange",
    "AudiencerangeRefname",
    "AudiencerangeShortname",
    "Avitem",
    "AvitemRefname",
    "AvitemShortname",
    "Avitemidentifier",
    "AvitemidentifierRefname",
    "AvitemidentifierShortname",
    "B012",
    "B012Refname",
    "B012Shortname",
    "B014",
    "B014Refname",
    "B014Shortname",
    "B020",
    "B020Refname",
    "B020Shortname",
    "B029",
    "B029Refname",
    "B029Shortname",
    "B030",
    "B030Refname",
    "B030Shortname",
    "B031",
    "B031Refname",
    "B031Shortname",
    "B034",
    "B034Refname",
    "B034Shortname",
    "B035",
    "B035Refname",
    "B035Shortname",
    "B036",
    "B036Refname",
    "B036Shortname",
    "B037",
    "B037Refname",
    "B037Shortname",
    "B038",
    "B038Refname",
    "B038Shortname",
    "B039",
    "B039Refname",
    "B039Shortname",
    "B040",
    "B040Refname",
    "B040Shortname",
    "B041",
    "B041Refname",
    "B041Shortname",
    "B042",
    "B042Refname",
    "B042Shortname",
    "B043",
    "B043Refname",
    "B043Shortname",
    "B044",
    "B044Refname",
    "B044Shortname",
    "B045",
    "B045Refname",
    "B045Shortname",
    "B046",
    "B046Refname",
    "B046Shortname",
    "B047",
    "B047Refname",
    "B047Shortname",
    "B048",
    "B048Refname",
    "B048Shortname",
    "B049",
    "B049Refname",
    "B049Shortname",
    "B051",
    "B051Refname",
    "B051Shortname",
    "B052",
    "B052Refname",
    "B052Shortname",
    "B053",
    "B053Refname",
    "B053Shortname",
    "B054",
    "B054Refname",
    "B054Shortname",
    "B055",
    "B055Refname",
    "B055Shortname",
    "B057",
    "B057Refname",
    "B057Shortname",
    "B058",
    "B058Refname",
    "B058Shortname",
    "B061",
    "B061Refname",
    "B061Shortname",
    "B062",
    "B062Refname",
    "B062Shortname",
    "B063",
    "B063Refname",
    "B063Shortname",
    "B067",
    "B067Refname",
    "B067Shortname",
    "B068",
    "B068Refname",
    "B068Shortname",
    "B069",
    "B069Refname",
    "B069Shortname",
    "B070",
    "B070Refname",
    "B070Shortname",
    "B073",
    "B073Refname",
    "B073Shortname",
    "B074",
    "B074Refname",
    "B074Shortname",
    "B075",
    "B075Refname",
    "B075Shortname",
    "B076",
    "B076Refname",
    "B076Shortname",
    "B077",
    "B077Refname",
    "B077Shortname",
    "B078",
    "B078Refname",
    "B078Shortname",
    "B079",
    "B079Refname",
    "B079Shortname",
    "B081",
    "B081Refname",
    "B081Shortname",
    "B083",
    "B083Refname",
    "B083Shortname",
    "B087",
    "B087Refname",
    "B087Shortname",
    "B089",
    "B089Refname",
    "B089Shortname",
    "B125",
    "B125Refname",
    "B125Shortname",
    "B171",
    "B171Refname",
    "B171Shortname",
    "B201",
    "B201Refname",
    "B201Shortname",
    "B202",
    "B202Refname",
    "B202Shortname",
    "B203",
    "B203Refname",
    "B203Shortname",
    "B204",
    "B204Refname",
    "B204Shortname",
    "B205",
    "B205Refname",
    "B205Shortname",
    "B206",
    "B206Refname",
    "B206Shortname",
    "B207",
    "B207Refname",
    "B207Shortname",
    "B209",
    "B209Refname",
    "B209Shortname",
    "B217",
    "B217Refname",
    "B217Shortname",
    "B218",
    "B218Refname",
    "B218Shortname",
    "B219",
    "B219Refname",
    "B219Shortname",
    "B220",
    "B220Refname",
    "B220Shortname",
    "B221",
    "B221Refname",
    "B221Shortname",
    "B225",
    "B225Refname",
    "B225Shortname",
    "B233",
    "B233Refname",
    "B233Shortname",
    "B244",
    "B244Refname",
    "B244Shortname",
    "B247",
    "B247Refname",
    "B247Shortname",
    "B248",
    "B248Refname",
    "B248Shortname",
    "B249",
    "B249Refname",
    "B249Shortname",
    "B251",
    "B251Refname",
    "B251Shortname",
    "B252",
    "B252Refname",
    "B252Shortname",
    "B253",
    "B253Refname",
    "B253Shortname",
    "B257",
    "B257Refname",
    "B257Shortname",
    "B274",
    "B274Refname",
    "B274Shortname",
    "B275",
    "B275Refname",
    "B275Shortname",
    "B284",
    "B284Refname",
    "B284Shortname",
    "B285",
    "B285Refname",
    "B285Shortname",
    "B286",
    "B286Refname",
    "B286Shortname",
    "B287",
    "B287Refname",
    "B287Shortname",
    "B288",
    "B288Refname",
    "B288Shortname",
    "B289",
    "B289Refname",
    "B289Shortname",
    "B290",
    "B290Refname",
    "B290Shortname",
    "B291",
    "B291Refname",
    "B291Shortname",
    "B294",
    "B294Refname",
    "B294Shortname",
    "B295",
    "B295Refname",
    "B295Shortname",
    "B306",
    "B306Refname",
    "B306Shortname",
    "B324",
    "B324Refname",
    "B324Shortname",
    "B325",
    "B325Refname",
    "B325Shortname",
    "B333",
    "B333Refname",
    "B333Shortname",
    "B334",
    "B334Refname",
    "B334Shortname",
    "B335",
    "B335Refname",
    "B335Shortname",
    "B336",
    "B336Refname",
    "B336Shortname",
    "B337",
    "B337Refname",
    "B337Shortname",
    "B341",
    "B341Refname",
    "B341Shortname",
    "B342",
    "B342Refname",
    "B342Shortname",
    "B352",
    "B352Refname",
    "B352Shortname",
    "B353",
    "B353Refname",
    "B353Shortname",
    "B354",
    "B354Refname",
    "B354Shortname",
    "B355",
    "B355Refname",
    "B355Shortname",
    "B356",
    "B356Refname",
    "B356Shortname",
    "B357",
    "B357Refname",
    "B357Shortname",
    "B358",
    "B358Refname",
    "B358Shortname",
    "B359",
    "B359Refname",
    "B359Shortname",
    "B360",
    "B360Refname",
    "B360Shortname",
    "B367",
    "B367Refname",
    "B367Shortname",
    "B368",
    "B368Refname",
    "B368Shortname",
    "B369",
    "B369Refname",
    "B369Shortname",
    "B370",
    "B370Refname",
    "B370Shortname",
    "B374",
    "B374Refname",
    "B374Shortname",
    "B376",
    "B376Refname",
    "B376Shortname",
    "B381",
    "B381Refname",
    "B381Shortname",
    "B382",
    "B382Refname",
    "B382Shortname",
    "B384",
    "B384Refname",
    "B384Shortname",
    "B385",
    "B385Refname",
    "B385Shortname",
    "B389",
    "B389Refname",
    "B389Shortname",
    "B391",
    "B391Refname",
    "B391Shortname",
    "B392",
    "B392Refname",
    "B392Shortname",
    "B393",
    "B393Refname",
    "B393Shortname",
    "B394",
    "B394Refname",
    "B394Shortname",
    "B395",
    "B395Refname",
    "B395Shortname",
    "B398",
    "B398Refname",
    "B398Shortname",
    "Barcode",
    "BarcodeRefname",
    "BarcodeShortname",
    "Batchbonus",
    "BatchbonusRefname",
    "BatchbonusShortname",
    "Bible",
    "BibleRefname",
    "BibleShortname",
    "Bodymanifest",
    "BodymanifestRefname",
    "BodymanifestShortname",
    "Bodyresource",
    "BodyresourceRefname",
    "BodyresourceShortname",
    "C094",
    "C094Refname",
    "C094Shortname",
    "C095",
    "C095Refname",
    "C095Shortname",
    "Citedcontent",
    "CitedcontentRefname",
    "CitedcontentShortname",
    "Collateraldetail",
    "CollateraldetailRefname",
    "CollateraldetailShortname",
    "Collection",
    "CollectionRefname",
    "CollectionShortname",
    "Collectionidentifier",
    "CollectionidentifierRefname",
    "CollectionidentifierShortname",
    "Collectionsequence",
    "CollectionsequenceRefname",
    "CollectionsequenceShortname",
    "Comparisonproductprice",
    "ComparisonproductpriceRefname",
    "ComparisonproductpriceShortname",
    "Complexity",
    "ComplexityRefname",
    "ComplexityShortname",
    "Conference",
    "ConferenceRefname",
    "ConferenceShortname",
    "Conferencesponsor",
    "ConferencesponsorRefname",
    "ConferencesponsorShortname",
    "Conferencesponsoridentifier",
    "ConferencesponsoridentifierRefname",
    "ConferencesponsoridentifierShortname",
    "Contentdate",
    "ContentdateRefname",
    "ContentdateShortname",
    "Contentdetail",
    "ContentdetailRefname",
    "ContentdetailShortname",
    "Contentitem",
    "ContentitemRefname",
    "ContentitemShortname",
    "Contributor",
    "ContributorRefname",
    "ContributorShortname",
    "Contributordate",
    "ContributordateRefname",
    "ContributordateShortname",
    "Contributorplace",
    "ContributorplaceRefname",
    "ContributorplaceShortname",
    "Contributorreference",
    "ContributorreferenceRefname",
    "ContributorreferenceShortname",
    "Copyrightowner",
    "CopyrightownerRefname",
    "CopyrightownerShortname",
    "Copyrightowneridentifier",
    "CopyrightowneridentifierRefname",
    "CopyrightowneridentifierShortname",
    "Copyrightstatement",
    "CopyrightstatementRefname",
    "CopyrightstatementShortname",
    "Covermanifest",
    "CovermanifestRefname",
    "CovermanifestShortname",
    "Coverresource",
    "CoverresourceRefname",
    "CoverresourceShortname",
    "D104",
    "D104Refname",
    "D104Shortname",
    "D107",
    "D107Refname",
    "D107Shortname",
    "Descriptivedetail",
    "DescriptivedetailRefname",
    "DescriptivedetailShortname",
    "Discount",
    "DiscountRefname",
    "DiscountShortname",
    "Discountcoded",
    "DiscountcodedRefname",
    "DiscountcodedShortname",
    "Epublicense",
    "EpublicenseRefname",
    "EpublicenseShortname",
    "Epublicenseexpression",
    "EpublicenseexpressionRefname",
    "EpublicenseexpressionShortname",
    "Epubusageconstraint",
    "EpubusageconstraintRefname",
    "EpubusageconstraintShortname",
    "Epubusagelimit",
    "EpubusagelimitRefname",
    "EpubusagelimitShortname",
    "Event",
    "EventRefname",
    "EventShortname",
    "Eventidentifier",
    "EventidentifierRefname",
    "EventidentifierShortname",
    "Eventoccurrence",
    "EventoccurrenceRefname",
    "EventoccurrenceShortname",
    "Eventsponsor",
    "EventsponsorRefname",
    "EventsponsorShortname",
    "Eventsponsoridentifier",
    "EventsponsoridentifierRefname",
    "EventsponsoridentifierShortname",
    "Extent",
    "ExtentRefname",
    "ExtentShortname",
    "Funding",
    "FundingRefname",
    "FundingShortname",
    "Fundingidentifier",
    "FundingidentifierRefname",
    "FundingidentifierShortname",
    "G126",
    "G126Refname",
    "G126Shortname",
    "G127",
    "G127Refname",
    "G127Shortname",
    "G128",
    "G128Refname",
    "G128Shortname",
    "G129",
    "G129Refname",
    "G129Shortname",
    "G343",
    "G343Refname",
    "G343Shortname",
    "Header",
    "HeaderRefname",
    "HeaderShortname",
    "Imprint",
    "ImprintRefname",
    "ImprintShortname",
    "Imprintidentifier",
    "ImprintidentifierRefname",
    "ImprintidentifierShortname",
    "Insertmanifest",
    "InsertmanifestRefname",
    "InsertmanifestShortname",
    "Insertpoint",
    "InsertpointRefname",
    "InsertpointShortname",
    "Insertresource",
    "InsertresourceRefname",
    "InsertresourceShortname",
    "J137",
    "J137Refname",
    "J137Shortname",
    "J144",
    "J144Refname",
    "J144Shortname",
    "J145",
    "J145Refname",
    "J145Shortname",
    "J151",
    "J151Refname",
    "J151Shortname",
    "J152",
    "J152Refname",
    "J152Shortname",
    "J192",
    "J192Refname",
    "J192Shortname",
    "J239",
    "J239Refname",
    "J239Shortname",
    "J260",
    "J260Refname",
    "J260Shortname",
    "J261",
    "J261Refname",
    "J261Shortname",
    "J262",
    "J262Refname",
    "J262Shortname",
    "J263",
    "J263Refname",
    "J263Shortname",
    "J264",
    "J264Refname",
    "J264Shortname",
    "J265",
    "J265Refname",
    "J265Shortname",
    "J266",
    "J266Refname",
    "J266Shortname",
    "J267",
    "J267Refname",
    "J267Shortname",
    "J268",
    "J268Refname",
    "J268Shortname",
    "J269",
    "J269Refname",
    "J269Shortname",
    "J270",
    "J270Refname",
    "J270Shortname",
    "J271",
    "J271Refname",
    "J271Shortname",
    "J272",
    "J272Refname",
    "J272Shortname",
    "J292",
    "J292Refname",
    "J292Shortname",
    "J293",
    "J293Refname",
    "J293Shortname",
    "J296",
    "J296Refname",
    "J296Shortname",
    "J297",
    "J297Refname",
    "J297Shortname",
    "J302",
    "J302Refname",
    "J302Shortname",
    "J345",
    "J345Refname",
    "J345Shortname",
    "J349",
    "J349Refname",
    "J349Shortname",
    "J350",
    "J350Refname",
    "J350Shortname",
    "J351",
    "J351Refname",
    "J351Shortname",
    "J363",
    "J363Refname",
    "J363Shortname",
    "J364",
    "J364Refname",
    "J364Shortname",
    "J365",
    "J365Refname",
    "J365Shortname",
    "J366",
    "J366Refname",
    "J366Shortname",
    "J375",
    "J375Refname",
    "J375Shortname",
    "J377",
    "J377Refname",
    "J377Shortname",
    "J378",
    "J378Refname",
    "J378Shortname",
    "J396",
    "J396Refname",
    "J396Shortname",
    "J400",
    "J400Refname",
    "J400Shortname",
    "J401",
    "J401Refname",
    "J401Shortname",
    "J402",
    "J402Refname",
    "J402Shortname",
    "J407",
    "J407Refname",
    "J407Shortname",
    "J408",
    "J408Refname",
    "J408Shortname",
    "K165",
    "K165Refname",
    "K165Shortname",
    "K166",
    "K166Refname",
    "K166Shortname",
    "K167",
    "K167Refname",
    "K167Shortname",
    "K168",
    "K168Refname",
    "K168Shortname",
    "K169",
    "K169Refname",
    "K169Shortname",
    "K309",
    "K309Refname",
    "K309Shortname",
    "Language",
    "LanguageRefname",
    "LanguageShortname",
    "Locationidentifier",
    "LocationidentifierRefname",
    "LocationidentifierShortname",
    "M180",
    "M180Refname",
    "M180Shortname",
    "M181",
    "M181Refname",
    "M181Shortname",
    "M183",
    "M183Refname",
    "M183Shortname",
    "M184",
    "M184Refname",
    "M184Shortname",
    "M186",
    "M186Refname",
    "M186Shortname",
    "M379",
    "M379Refname",
    "M379Shortname",
    "M380",
    "M380Refname",
    "M380Shortname",
    "Market",
    "MarketRefname",
    "MarketShortname",
    "Marketdate",
    "MarketdateRefname",
    "MarketdateShortname",
    "Marketpublishingdetail",
    "MarketpublishingdetailRefname",
    "MarketpublishingdetailShortname",
    "Measure",
    "MeasureRefname",
    "MeasureShortname",
    "N339",
    "N339Refname",
    "N339Shortname",
    "N386",
    "N386Refname",
    "N386Shortname",
    "Nameassubject",
    "NameassubjectRefname",
    "NameassubjectShortname",
    "Nameidentifier",
    "NameidentifierRefname",
    "NameidentifierShortname",
    "Newsupplier",
    "NewsupplierRefname",
    "NewsupplierShortname",
    "Occurrencedate",
    "OccurrencedateRefname",
    "OccurrencedateShortname",
    "Onorderdetail",
    "OnorderdetailRefname",
    "OnorderdetailShortname",
    "Pagerun",
    "PagerunRefname",
    "PagerunShortname",
    "Price",
    "PriceRefname",
    "PriceShortname",
    "Pricecoded",
    "PricecodedRefname",
    "PricecodedShortname",
    "Pricecondition",
    "PriceconditionRefname",
    "PriceconditionShortname",
    "Priceconditionquantity",
    "PriceconditionquantityRefname",
    "PriceconditionquantityShortname",
    "Priceconstraint",
    "PriceconstraintRefname",
    "PriceconstraintShortname",
    "Priceconstraintlimit",
    "PriceconstraintlimitRefname",
    "PriceconstraintlimitShortname",
    "Pricedate",
    "PricedateRefname",
    "PricedateShortname",
    "Priceidentifier",
    "PriceidentifierRefname",
    "PriceidentifierShortname",
    "Prize",
    "PrizeRefname",
    "PrizeShortname",
    "Product",
    "ProductRefname",
    "ProductShortname",
    "Productclassification",
    "ProductclassificationRefname",
    "ProductclassificationShortname",
    "Productcontact",
    "ProductcontactRefname",
    "ProductcontactShortname",
    "Productcontactidentifier",
    "ProductcontactidentifierRefname",
    "ProductcontactidentifierShortname",
    "Productformfeature",
    "ProductformfeatureRefname",
    "ProductformfeatureShortname",
    "Productidentifier",
    "ProductidentifierRefname",
    "ProductidentifierShortname",
    "Productiondetail",
    "ProductiondetailRefname",
    "ProductiondetailShortname",
    "Productionmanifest",
    "ProductionmanifestRefname",
    "ProductionmanifestShortname",
    "Productpart",
    "ProductpartRefname",
    "ProductpartShortname",
    "Productsupply",
    "ProductsupplyRefname",
    "ProductsupplyShortname",
    "Professionalaffiliation",
    "ProfessionalaffiliationRefname",
    "ProfessionalaffiliationShortname",
    "Promotionalevent",
    "PromotionaleventRefname",
    "PromotionaleventShortname",
    "Promotiondetail",
    "PromotiondetailRefname",
    "PromotiondetailShortname",
    "Publisher",
    "PublisherRefname",
    "PublisherShortname",
    "Publisheridentifier",
    "PublisheridentifierRefname",
    "PublisheridentifierShortname",
    "Publisherrepresentative",
    "PublisherrepresentativeRefname",
    "PublisherrepresentativeShortname",
    "Publishingdate",
    "PublishingdateRefname",
    "PublishingdateShortname",
    "Publishingdetail",
    "PublishingdetailRefname",
    "PublishingdetailShortname",
    "Recordsourceidentifier",
    "RecordsourceidentifierRefname",
    "RecordsourceidentifierShortname",
    "Reissue",
    "ReissueRefname",
    "ReissueShortname",
    "Relatedmaterial",
    "RelatedmaterialRefname",
    "RelatedmaterialShortname",
    "Relatedproduct",
    "RelatedproductRefname",
    "RelatedproductShortname",
    "Relatedwork",
    "RelatedworkRefname",
    "RelatedworkShortname",
    "ReleaseAttributeRelease",
    "Religioustext",
    "ReligioustextRefname",
    "ReligioustextShortname",
    "Religioustextfeature",
    "ReligioustextfeatureRefname",
    "ReligioustextfeatureShortname",
    "Resourcefeature",
    "ResourcefeatureRefname",
    "ResourcefeatureShortname",
    "Resourcefiledate",
    "ResourcefiledateRefname",
    "ResourcefiledateShortname",
    "Resourcefilefeature",
    "ResourcefilefeatureRefname",
    "ResourcefilefeatureShortname",
    "Resourceidentifier",
    "ResourceidentifierRefname",
    "ResourceidentifierShortname",
    "Resourceversion",
    "ResourceversionRefname",
    "ResourceversionShortname",
    "Resourceversionfeature",
    "ResourceversionfeatureRefname",
    "ResourceversionfeatureShortname",
    "Returnsconditions",
    "ReturnsconditionsRefname",
    "ReturnsconditionsShortname",
    "Reviewrating",
    "ReviewratingRefname",
    "ReviewratingShortname",
    "Salesoutlet",
    "SalesoutletRefname",
    "SalesoutletShortname",
    "Salesoutletidentifier",
    "SalesoutletidentifierRefname",
    "SalesoutletidentifierShortname",
    "Salesrestriction",
    "SalesrestrictionRefname",
    "SalesrestrictionShortname",
    "Salesrights",
    "SalesrightsRefname",
    "SalesrightsShortname",
    "Sender",
    "SenderRefname",
    "SenderShortname",
    "Senderidentifier",
    "SenderidentifierRefname",
    "SenderidentifierShortname",
    "Specificationbundlename",
    "SpecificationbundlenameRefname",
    "SpecificationbundlenameShortname",
    "Specificationfeature",
    "SpecificationfeatureRefname",
    "SpecificationfeatureShortname",
    "Stock",
    "StockRefname",
    "StockShortname",
    "Stockquantitycoded",
    "StockquantitycodedRefname",
    "StockquantitycodedShortname",
    "Subject",
    "SubjectRefname",
    "SubjectShortname",
    "Subjectdate",
    "SubjectdateRefname",
    "SubjectdateShortname",
    "Supplementmanifest",
    "SupplementmanifestRefname",
    "SupplementmanifestShortname",
    "Supplier",
    "SupplierRefname",
    "SupplierShortname",
    "Supplieridentifier",
    "SupplieridentifierRefname",
    "SupplieridentifierShortname",
    "Supplierowncoding",
    "SupplierowncodingRefname",
    "SupplierowncodingShortname",
    "Supplycontact",
    "SupplycontactRefname",
    "SupplycontactShortname",
    "Supplycontactidentifier",
    "SupplycontactidentifierRefname",
    "SupplycontactidentifierShortname",
    "Supplydate",
    "SupplydateRefname",
    "SupplydateShortname",
    "Supplydetail",
    "SupplydetailRefname",
    "SupplydetailShortname",
    "Supportingresource",
    "SupportingresourceRefname",
    "SupportingresourceShortname",
    "Tax",
    "TaxRefname",
    "TaxShortname",
    "Territory",
    "TerritoryRefname",
    "TerritoryShortname",
    "Textcontent",
    "TextcontentRefname",
    "TextcontentShortname",
    "Textitem",
    "TextitemRefname",
    "TextitemShortname",
    "Textitemidentifier",
    "TextitemidentifierRefname",
    "TextitemidentifierShortname",
    "Timerun",
    "TimerunRefname",
    "TimerunShortname",
    "Titledetail",
    "TitledetailRefname",
    "TitledetailShortname",
    "Titleelement",
    "TitleelementRefname",
    "TitleelementShortname",
    "Velocity",
    "VelocityRefname",
    "VelocityShortname",
    "Website",
    "WebsiteRefname",
    "WebsiteShortname",
    "Workidentifier",
    "WorkidentifierRefname",
    "WorkidentifierShortname",
    "X298",
    "X298Refname",
    "X298Shortname",
    "X299",
    "X299Refname",
    "X299Shortname",
    "X300",
    "X300Refname",
    "X300Shortname",
    "X301",
    "X301Refname",
    "X301Shortname",
    "X307",
    "X307Refname",
    "X307Shortname",
    "X310",
    "X310Refname",
    "X310Shortname",
    "X311",
    "X311Refname",
    "X311Shortname",
    "X312",
    "X312Refname",
    "X312Shortname",
    "X313",
    "X313Refname",
    "X313Shortname",
    "X314",
    "X314Refname",
    "X314Shortname",
    "X315",
    "X315Refname",
    "X315Shortname",
    "X316",
    "X316Refname",
    "X316Shortname",
    "X317",
    "X317Refname",
    "X317Shortname",
    "X318",
    "X318Refname",
    "X318Shortname",
    "X319",
    "X319Refname",
    "X319Shortname",
    "X320",
    "X320Refname",
    "X320Shortname",
    "X321",
    "X321Refname",
    "X321Shortname",
    "X322",
    "X322Refname",
    "X322Shortname",
    "X323",
    "X323Refname",
    "X323Shortname",
    "X329",
    "X329Refname",
    "X329Shortname",
    "X330",
    "X330Refname",
    "X330Shortname",
    "X344",
    "X344Refname",
    "X344Shortname",
    "X406",
    "X406Refname",
    "X406Shortname",
    "X409",
    "X409Refname",
    "X409Shortname",
    "X410",
    "X410Refname",
    "X410Shortname",
    "X411",
    "X411Refname",
    "X411Shortname",
    "X412",
    "X412Refname",
    "X412Shortname",
    "X413",
    "X413Refname",
    "X413Shortname",
    "X414",
    "X414Refname",
    "X414Shortname",
    "X415",
    "X415Refname",
    "X415Shortname",
    "X416",
    "X416Refname",
    "X416Shortname",
    "X417",
    "X417Refname",
    "X417Shortname",
    "X418",
    "X418Refname",
    "X418Shortname",
    "X419",
    "X419Refname",
    "X419Shortname",
    "X420",
    "X420Refname",
    "X420Shortname",
    "X421",
    "X421Refname",
    "X421Shortname",
    "X422",
    "X422Refname",
    "X422Shortname",
    "X423",
    "X423Refname",
    "X423Shortname",
    "X424",
    "X424Refname",
    "X424Shortname",
    "X425",
    "X425Refname",
    "X425Shortname",
    "X426",
    "X426Refname",
    "X426Shortname",
    "X427",
    "X427Refname",
    "X427Shortname",
    "X428",
    "X428Refname",
    "X428Shortname",
    "X429",
    "X429Refname",
    "X429Shortname",
    "X430",
    "X430Refname",
    "X430Shortname",
    "X431",
    "X431Refname",
    "X431Shortname",
    "X432",
    "X432Refname",
    "X432Shortname",
    "X433",
    "X433Refname",
    "X433Shortname",
    "X434",
    "X434Refname",
    "X434Shortname",
    "X435",
    "X435Refname",
    "X435Shortname",
    "X436",
    "X436Refname",
    "X436Shortname",
    "X437",
    "X437Refname",
    "X437Shortname",
    "X438",
    "X438Refname",
    "X438Shortname",
    "X439",
    "X439Refname",
    "X439Shortname",
    "X440",
    "X440Refname",
    "X440Shortname",
    "X441",
    "X441Refname",
    "X441Shortname",
    "X442",
    "X442Refname",
    "X442Shortname",
    "X443",
    "X443Refname",
    "X443Shortname",
    "X445",
    "X445Refname",
    "X445Shortname",
    "X446",
    "X446Refname",
    "X446Shortname",
    "X447",
    "X447Refname",
    "X447Shortname",
    "X448",
    "X448Refname",
    "X448Shortname",
    "X449",
    "X449Refname",
    "X449Shortname",
    "X450",
    "X450Refname",
    "X450Shortname",
    "X451",
    "X451Refname",
    "X451Shortname",
    "X452",
    "X452Refname",
    "X452Shortname",
    "X453",
    "X453Refname",
    "X453Shortname",
    "X454",
    "X454Refname",
    "X454Shortname",
    "X455",
    "X455Refname",
    "X455Shortname",
    "X456",
    "X456Refname",
    "X456Shortname",
    "X457",
    "X457Refname",
    "X457Shortname",
    "X458",
    "X458Refname",
    "X458Shortname",
    "X459",
    "X459Refname",
    "X459Shortname",
    "X460",
    "X460Refname",
    "X460Shortname",
    "X461",
    "X461Refname",
    "X461Shortname",
    "X462",
    "X462Refname",
    "X462Shortname",
    "X463",
    "X463Refname",
    "X463Shortname",
    "X464",
    "X464Refname",
    "X464Shortname",
    "X465",
    "X465Refname",
    "X465Shortname",
    "X466",
    "X466Refname",
    "X466Shortname",
    "X467",
    "X467Refname",
    "X467Shortname",
    "X468",
    "X468Refname",
    "X468Shortname",
    "X469",
    "X469Refname",
    "X469Shortname",
    "X470",
    "X470Refname",
    "X470Shortname",
    "X471",
    "X471Refname",
    "X471Shortname",
    "X472",
    "X472Refname",
    "X472Shortname",
    "X473",
    "X473Refname",
    "X473Shortname",
    "X474",
    "X474Refname",
    "X474Shortname",
    "X475",
    "X475Refname",
    "X475Shortname",
    "X476",
    "X476Refname",
    "X476Shortname",
    "X477",
    "X477Refname",
    "X477Shortname",
    "X478",
    "X478Refname",
    "X478Shortname",
    "X479",
    "X479Refname",
    "X479Shortname",
    "X480",
    "X480Refname",
    "X480Shortname",
    "X481",
    "X481Refname",
    "X481Shortname",
    "X482",
    "X482Refname",
    "X482Shortname",
    "X483",
    "X483Refname",
    "X483Shortname",
    "X484",
    "X484Refname",
    "X484Shortname",
    "X501",
    "X501Refname",
    "X501Shortname",
    "X502",
    "X502Refname",
    "X502Shortname",
    "X503",
    "X503Refname",
    "X503Shortname",
    "X504",
    "X504Refname",
    "X504Shortname",
    "X505",
    "X505Refname",
    "X505Shortname",
    "X506",
    "X506Refname",
    "X506Shortname",
    "X507",
    "X507Refname",
    "X507Shortname",
    "X508",
    "X508Refname",
    "X508Shortname",
    "X509",
    "X509Refname",
    "X509Shortname",
    "X510",
    "X510Refname",
    "X510Shortname",
    "X511",
    "X511Refname",
    "X511Shortname",
    "X512",
    "X512Refname",
    "X512Shortname",
    "X513",
    "X513Refname",
    "X513Shortname",
    "X514",
    "X514Refname",
    "X514Shortname",
    "X515",
    "X515Refname",
    "X515Shortname",
    "X516",
    "X516Refname",
    "X516Shortname",
    "X517",
    "X517Refname",
    "X517Shortname",
    "X518",
    "X518Refname",
    "X518Shortname",
    "X519",
    "X519Refname",
    "X519Shortname",
    "X520",
    "X520Refname",
    "X520Shortname",
    "X521",
    "X521Refname",
    "X521Shortname",
    "X522",
    "X522Refname",
    "X522Shortname",
    "X523",
    "X523Refname",
    "X523Shortname",
    "X524",
    "X524Refname",
    "X524Shortname",
    "X525",
    "X525Refname",
    "X525Shortname",
    "X526",
    "X526Refname",
    "X526Shortname",
    "X527",
    "X527Refname",
    "X527Shortname",
    "X528",
    "X528Refname",
    "X528Shortname",
    "X529",
    "X529Refname",
    "X529Shortname",
    "X530",
    "X530Refname",
    "X530Shortname",
    "X531",
    "X531Refname",
    "X531Shortname",
    "X532",
    "X532Refname",
    "X532Shortname",
    "X533",
    "X533Refname",
    "X533Shortname",
    "X534",
    "X534Refname",
    "X534Shortname",
    "X535",
    "X535Refname",
    "X535Shortname",
    "X536",
    "X536Refname",
    "X536Shortname",
    "X537",
    "X537Refname",
    "X537Shortname",
    "X538",
    "X538Refname",
    "X538Shortname",
    "X539",
    "X539Refname",
    "X539Shortname",
    "X540",
    "X540Refname",
    "X540Shortname",
    "X541",
    "X541Refname",
    "X541Shortname",
    "X542",
    "X542Refname",
    "X542Shortname",
    "X543",
    "X543Refname",
    "X543Shortname",
    "X544",
    "X544Refname",
    "X544Shortname",
    "X545",
    "X545Refname",
    "X545Shortname",
    "X546",
    "X546Refname",
    "X546Shortname",
    "X547",
    "X547Refname",
    "X547Shortname",
    "X548",
    "X548Refname",
    "X548Shortname",
    "X549",
    "X549Refname",
    "X549Shortname",
    "X550",
    "X550Refname",
    "X550Shortname",
    "X551",
    "X551Refname",
    "X551Shortname",
    "X552",
    "X552Refname",
    "X552Shortname",
    "X553",
    "X553Refname",
    "X553Shortname",
    "X554",
    "X554Refname",
    "X554Shortname",
    "X555",
    "X555Refname",
    "X555Shortname",
    "X556",
    "X556Refname",
    "X556Shortname",
    "X557",
    "X557Refname",
    "X557Shortname",
    "X558",
    "X558Refname",
    "X558Shortname",
    "X559",
    "X559Refname",
    "X559Shortname",
    "X560",
    "X560Refname",
    "X560Shortname",
    "X561",
    "X561Refname",
    "X561Shortname",
    "X562",
    "X562Refname",
    "X562Shortname",
    "X563",
    "X563Refname",
    "X563Shortname",
    "X564",
    "X564Refname",
    "X564Shortname",
    "X565",
    "X565Refname",
    "X565Shortname",
    "X566",
    "X566Refname",
    "X566Shortname",
    "X567",
    "X567Refname",
    "X567Shortname",
    "X568",
    "X568Refname",
    "X568Shortname",
    "X569",
    "X569Refname",
    "X569Shortname",
    "X570",
    "X570Refname",
    "X570Shortname",
    "X571",
    "X571Refname",
    "X571Shortname",
    "X572",
    "X572Refname",
    "X572Shortname",
    "X573",
    "X573Refname",
    "X573Shortname",
    "X574",
    "X574Refname",
    "X574Shortname",
    "X575",
    "X575Refname",
    "X575Shortname",
    "X576",
    "X576Refname",
    "X576Shortname",
    "X577",
    "X577Refname",
    "X577Shortname",
    "X578",
    "X578Refname",
    "X578Shortname",
    "X579",
    "X579Refname",
    "X579Shortname",
    "List1",
    "List100",
    "List102",
    "List12",
    "List121",
    "List13",
    "List14",
    "List141",
    "List142",
    "List144",
    "List145",
    "List146",
    "List147",
    "List148",
    "List149",
    "List15",
    "List150",
    "List151",
    "List152",
    "List153",
    "List154",
    "List155",
    "List156",
    "List157",
    "List158",
    "List159",
    "List16",
    "List160",
    "List161",
    "List162",
    "List163",
    "List164",
    "List165",
    "List166",
    "List167",
    "List168",
    "List169",
    "List17",
    "List170",
    "List171",
    "List172",
    "List173",
    "List174",
    "List175",
    "List177",
    "List179",
    "List18",
    "List19",
    "List197",
    "List198",
    "List2",
    "List20",
    "List21",
    "List215",
    "List216",
    "List217",
    "List218",
    "List219",
    "List22",
    "List228",
    "List229",
    "List23",
    "List230",
    "List239",
    "List24",
    "List240",
    "List241",
    "List244",
    "List245",
    "List246",
    "List247",
    "List248",
    "List249",
    "List25",
    "List250",
    "List252",
    "List253",
    "List254",
    "List255",
    "List27",
    "List28",
    "List29",
    "List3",
    "List30",
    "List31",
    "List32",
    "List34",
    "List41",
    "List42",
    "List43",
    "List44",
    "List45",
    "List46",
    "List48",
    "List49",
    "List5",
    "List50",
    "List51",
    "List53",
    "List55",
    "List57",
    "List58",
    "List59",
    "List60",
    "List61",
    "List62",
    "List64",
    "List65",
    "List68",
    "List69",
    "List70",
    "List71",
    "List72",
    "List73",
    "List74",
    "List79",
    "List80",
    "List81",
    "List82",
    "List83",
    "List84",
    "List85",
    "List86",
    "List87",
    "List89",
    "List9",
    "List90",
    "List91",
    "List92",
    "List93",
    "List96",
    "List97",
    "Block",
    "Flow",
    "Inline",
    "Scope",
    "Shape",
    "Tframe",
    "Trules",
    "A",
    "AContent",
    "Abbr",
    "Acronym",
    "Address",
    "Area",
    "AreaAttlistNohref",
    "B",
    "Bdo",
    "BdoAttlistDir",
    "Big",
    "Blockquote",
    "Br",
    "Caption",
    "CellhalignAlign",
    "CellvalignValign",
    "Cite",
    "Code",
    "Col",
    "Colgroup",
    "Dd",
    "Dfn",
    "Div",
    "Dl",
    "Dt",
    "Em",
    "H1",
    "H2",
    "H3",
    "H4",
    "H5",
    "H6",
    "Hr",
    "I",
    "I18NDir",
    "Img",
    "ImgAttlistIsmap",
    "Kbd",
    "Li",
    "Map",
    "Ol",
    "P",
    "Pre",
    "PreContent",
    "Q",
    "Rb",
    "Rbc",
    "Rp",
    "Rt",
    "Rtc",
    "Ruby",
    "RubyContent",
    "Samp",
    "Small",
    "Span",
    "Strong",
    "Sub",
    "Sup",
    "Table",
    "Tbody",
    "Td",
    "Tfoot",
    "Th",
    "Thead",
    "Tr",
    "Tt",
    "Ul",
    "Var",
]
