from onix.book.v2_1.reference.book_2_1_reference import (
    AbbreviatedLength,
    AddresseeIdtype,
    AddresseeIdentifier,
    Affiliation,
    AgentIdtype,
    AgentIdentifier,
    AgentName,
    AgentRole,
    AlternativeFormatEan13,
    AlternativeFormatIsbn,
    AlternativeProductEan13,
    AlternativeProductIsbn,
    Annotation,
    AnnouncementDate,
    Audience,
    AudienceCode,
    AudienceCodeType,
    AudienceCodeTypeName,
    AudienceCodeValue,
    AudienceDescription,
    AudienceRange,
    AudienceRangePrecision,
    AudienceRangeQualifier,
    AudienceRangeValue,
    AudienceRestrictionFlag,
    AudienceRestrictionNote,
    AvailabilityCode,
    BasicmainSubject,
    Basicversion,
    BicdiscountGroupCode,
    BicmainSubject,
    Bicversion,
    Barcode,
    BatchBonus,
    BatchQuantity,
    Bible,
    BibleContents,
    BiblePurpose,
    BibleReferenceLocation,
    BibleTextFeature,
    BibleTextOrganization,
    BibleVersion,
    BiographicalNote,
    BookClubAdoption,
    BookFormDetail,
    Cbo,
    CityOfPublication,
    ClassOfTrade,
    Complexity,
    ComplexityCode,
    ComplexitySchemeIdentifier,
    ComponentNumber,
    ComponentTypeName,
    Conference,
    ConferenceAcronym,
    ConferenceDate,
    ConferenceDescription,
    ConferenceName,
    ConferenceNumber,
    ConferencePlace,
    ConferenceRole,
    ConferenceSponsor,
    ConferenceSponsorIdtype,
    ConferenceSponsorIdentifier,
    ConferenceTheme,
    ContainedItem,
    ContentItem,
    Contributor,
    ContributorDescription,
    ContributorRole,
    ContributorStatement,
    CopiesSold,
    CopublisherName,
    CopyrightOwner,
    CopyrightOwnerIdtype,
    CopyrightOwnerIdentifier,
    CopyrightStatement,
    CopyrightYear,
    CorporateBodyAsSubject,
    CorporateName,
    CountryCode,
    CountryExcluded,
    CountryOfPublication,
    CoverImageFormatCode,
    CoverImageLink,
    CoverImageLinkTypeCode,
    CurrencyCode,
    Doi,
    Date,
    DateFormat,
    DefaultClassOfTrade,
    DefaultCurrencyCode,
    DefaultLanguageOfText,
    DefaultLinearUnit,
    DefaultPriceTypeCode,
    DefaultWeightUnit,
    DeletionCode,
    DeletionText,
    Dimensions,
    DiscountCode,
    DiscountCodeType,
    DiscountCodeTypeName,
    DiscountCoded,
    DiscountPercent,
    DistinctiveTitle,
    DownloadCaption,
    DownloadCopyrightNotice,
    DownloadCredit,
    DownloadTerms,
    Ean13,
    Ean13OfSet,
    EditionNumber,
    EditionStatement,
    EditionTypeCode,
    EditionVersionNumber,
    EmailAddress,
    EndDate,
    EpubFormat,
    EpubFormatDescription,
    EpubFormatVersion,
    EpubSource,
    EpubSourceDescription,
    EpubSourceVersion,
    EpubType,
    EpubTypeDescription,
    EpubTypeNote,
    EpubTypeVersion,
    ExpectedDate,
    ExpectedShipDate,
    Extent,
    ExtentType,
    ExtentUnit,
    ExtentValue,
    FaxNumber,
    FirstPageNumber,
    FormerTitle,
    FreeQuantity,
    FromCompany,
    FromEannumber,
    FromEmail,
    FromPerson,
    FromSan,
    Header,
    Height,
    IdtypeName,
    Idvalue,
    Isbn,
    IsbnofSet,
    Ismn,
    IllustrationType,
    IllustrationTypeDescription,
    Illustrations,
    IllustrationsNote,
    ImageResolution,
    Imprint,
    ImprintName,
    InitialPrintRun,
    InterestAge,
    IntermediaryAvailabilityCode,
    ItemNumberWithinSet,
    ItemQuantity,
    KeyNames,
    Language,
    LanguageCode,
    LanguageOfText,
    LanguageRole,
    LastDateForReturns,
    LastPageNumber,
    LettersAfterNames,
    LevelSequenceNumber,
    LocationIdtype,
    LocationIdentifier,
    LocationName,
    MainDescription,
    MainSeriesRecord,
    MainSubject,
    MainSubjectSchemeIdentifier,
    MapScale,
    MarketCountry,
    MarketCountryExcluded,
    MarketDate,
    MarketDateRole,
    MarketPublishingStatus,
    MarketRepresentation,
    MarketRestrictionDetail,
    MarketTerritory,
    Measure,
    MeasureTypeCode,
    MeasureUnitCode,
    Measurement,
    MediaFile,
    MediaFileDate,
    MediaFileFormatCode,
    MediaFileLink,
    MediaFileLinkTypeCode,
    MediaFileTypeCode,
    MessageNote,
    MessageNumber,
    MessageRepeat,
    MinimumOrderQuantity,
    Name,
    NameCodeType,
    NameCodeTypeName,
    NameCodeValue,
    NamesAfterKey,
    NamesBeforeKey,
    NewSupplier,
    NoContributor,
    NoEdition,
    NoSeries,
    NotForSale,
    NotificationType,
    Number,
    NumberOfIllustrations,
    NumberOfPages,
    NumberOfPieces,
    NumberWithinSeries,
    Onixmessage,
    OnHand,
    OnOrder,
    OnOrderDetail,
    OnSaleDate,
    OrderTime,
    OriginalLanguage,
    OriginalPublisher,
    OtherText,
    OutOfPrintDate,
    PackQuantity,
    PageRun,
    PagesArabic,
    PagesRoman,
    ParentIdentifier,
    Percent,
    PersonAsSubject,
    PersonDate,
    PersonDateRole,
    PersonName,
    PersonNameIdtype,
    PersonNameIdentifier,
    PersonNameInverted,
    PersonNameType,
    PlaceAsSubject,
    PrefixToKey,
    Price,
    PriceAmount,
    PriceEffectiveFrom,
    PriceEffectiveUntil,
    PricePer,
    PriceQualifier,
    PriceStatus,
    PriceTypeCode,
    PriceTypeDescription,
    Prize,
    PrizeCode,
    PrizeCountry,
    PrizeJury,
    PrizeName,
    PrizeYear,
    PrizesDescription,
    Product,
    ProductAvailability,
    ProductClassification,
    ProductClassificationCode,
    ProductClassificationType,
    ProductContentType,
    ProductForm,
    ProductFormDescription,
    ProductFormDetail,
    ProductFormFeature,
    ProductFormFeatureDescription,
    ProductFormFeatureType,
    ProductFormFeatureValue,
    ProductIdtype,
    ProductIdentifier,
    ProductPackaging,
    ProductWebsite,
    ProductWebsiteDescription,
    ProductWebsiteLink,
    ProfessionalAffiliation,
    ProfessionalPosition,
    PromotionCampaign,
    PromotionContact,
    PublicationDate,
    Publisher,
    PublisherName,
    PublisherProductNo,
    PublisherSeriesCode,
    PublishingRole,
    PublishingStatus,
    PublishingStatusNote,
    RecordReference,
    RecordSourceIdentifier,
    RecordSourceIdentifierType,
    RecordSourceName,
    RecordSourceType,
    RegionCode,
    Reissue,
    ReissueDate,
    ReissueDescription,
    RelatedProduct,
    RelationCode,
    ReligiousText,
    ReligiousTextFeature,
    ReligiousTextFeatureCode,
    ReligiousTextFeatureDescription,
    ReligiousTextFeatureType,
    ReligiousTextId,
    ReplacedByEan13,
    ReplacedByIsbn,
    ReplacesEan13,
    ReplacesIsbn,
    ReprintDetail,
    ReturnsCode,
    ReturnsCodeType,
    ReviewQuote,
    RightsCountry,
    RightsRegion,
    RightsTerritory,
    SalesOutlet,
    SalesOutletIdtype,
    SalesOutletIdentifier,
    SalesOutletName,
    SalesRestriction,
    SalesRestrictionDetail,
    SalesRestrictionType,
    SalesRights,
    SalesRightsType,
    SenderIdtype,
    SenderIdentifier,
    SentDate,
    SequenceNumber,
    SequenceNumberWithinRole,
    Series,
    SeriesIdtype,
    SeriesIssn,
    SeriesIdentifier,
    SeriesPartName,
    Set,
    SetItemTitle,
    SetPartNumber,
    SetPartTitle,
    SponsorName,
    StartDate,
    Stock,
    StockQuantityCode,
    StockQuantityCodeType,
    StockQuantityCodeTypeName,
    StockQuantityCoded,
    StudyBibleType,
    SubSeriesRecord,
    Subject,
    SubjectCode,
    SubjectHeadingText,
    SubjectSchemeIdentifier,
    SubjectSchemeName,
    SubjectSchemeVersion,
    SubordinateEntries,
    Subtitle,
    SuffixToKey,
    SupplierEanlocationNumber,
    SupplierIdtype,
    SupplierIdentifier,
    SupplierName,
    SupplierRole,
    SupplierSan,
    SupplyDetail,
    SupplyRestrictionDetail,
    SupplyToCountry,
    SupplyToCountryExcluded,
    SupplyToRegion,
    SupplyToTerritory,
    TaxAmount1,
    TaxAmount2,
    TaxRateCode1,
    TaxRateCode2,
    TaxRatePercent1,
    TaxRatePercent2,
    TaxableAmount1,
    TaxableAmount2,
    TelephoneNumber,
    Territory,
    TerritoryExcluded,
    Text,
    TextAuthor,
    TextCaseFlag,
    TextFormat,
    TextItem,
    TextItemIdtype,
    TextItemIdentifier,
    TextItemType,
    TextLink,
    TextLinkType,
    TextPublicationDate,
    TextSourceCorporate,
    TextSourceTitle,
    TextTypeCode,
    TextWithDownload,
    ThesisPresentedTo,
    ThesisType,
    ThesisYear,
    Thickness,
    Title,
    TitleOfSeries,
    TitleOfSet,
    TitlePrefix,
    TitleText,
    TitleType,
    TitleWithoutPrefix,
    TitlesAfterNames,
    TitlesBeforeNames,
    ToCompany,
    ToEannumber,
    ToPerson,
    ToSan,
    TradeAnnouncementDate,
    TradeCategory,
    TranslationOfTitle,
    Upc,
    UsschoolGrade,
    UnnamedPersons,
    UnpricedItemType,
    Website,
    WebsiteDescription,
    WebsiteLink,
    WebsiteRole,
    Weight,
    Width,
    WorkIdtype,
    WorkIdentifier,
    YearFirstPublished,
    YearOfAnnual,
)
from onix.book.v2_1.reference.onix_book_product_code_lists import (
    List1,
    List10,
    List100,
    List101,
    List102,
    List11,
    List12,
    List13,
    List138,
    List14,
    List15,
    List16,
    List17,
    List18,
    List19,
    List2,
    List20,
    List21,
    List22,
    List23,
    List24,
    List25,
    List26,
    List27,
    List28,
    List29,
    List3,
    List30,
    List31,
    List32,
    List33,
    List34,
    List35,
    List36,
    List37,
    List38,
    List39,
    List40,
    List41,
    List42,
    List43,
    List44,
    List45,
    List46,
    List47,
    List48,
    List49,
    List5,
    List50,
    List51,
    List52,
    List53,
    List54,
    List55,
    List56,
    List57,
    List58,
    List59,
    List6,
    List60,
    List61,
    List62,
    List64,
    List65,
    List7,
    List70,
    List71,
    List72,
    List73,
    List74,
    List75,
    List78,
    List79,
    List8,
    List80,
    List81,
    List82,
    List83,
    List84,
    List85,
    List86,
    List87,
    List89,
    List9,
    List90,
    List91,
    List92,
    List93,
    List94,
    List95,
    List96,
    List97,
)
from onix.book.v2_1.reference.onix_xhtml_subset import (
    A,
    ADir,
    AShape,
    Abbr,
    AbbrDir,
    Acronym,
    AcronymDir,
    Address,
    AddressDir,
    Area,
    AreaDir,
    AreaNohref,
    AreaShape,
    B,
    BDir,
    Bdo,
    BdoDir,
    Big,
    BigDir,
    Blockquote,
    BlockquoteDir,
    Br,
    Caption,
    CaptionDir,
    Cite,
    CiteDir,
    Code,
    CodeDir,
    Col,
    ColAlign,
    ColDir,
    ColValign,
    Colgroup,
    ColgroupAlign,
    ColgroupDir,
    ColgroupValign,
    Dd,
    DdDir,
    Dfn,
    DfnDir,
    Div,
    DivDir,
    Dl,
    DlDir,
    Dt,
    DtDir,
    Em,
    EmDir,
    H1,
    H1Dir,
    H2,
    H2Dir,
    H3,
    H3Dir,
    H4,
    H4Dir,
    H5,
    H5Dir,
    H6,
    H6Dir,
    Hr,
    HrDir,
    I,
    IDir,
    Img,
    ImgDir,
    ImgIsmap,
    Kbd,
    KbdDir,
    Li,
    LiDir,
    Map,
    MapDir,
    Object,
    ObjectDeclare,
    ObjectDir,
    Ol,
    OlDir,
    P,
    PDir,
    Param,
    ParamValuetype,
    Pre,
    PreDir,
    Q,
    QDir,
    Samp,
    SampDir,
    Small,
    SmallDir,
    Span,
    SpanDir,
    Strong,
    StrongDir,
    Sub,
    SubDir,
    Sup,
    SupDir,
    Table,
    TableDir,
    TableFrame,
    TableRules,
    Tbody,
    TbodyAlign,
    TbodyDir,
    TbodyValign,
    Td,
    TdAlign,
    TdDir,
    TdScope,
    TdValign,
    Tfoot,
    TfootAlign,
    TfootDir,
    TfootValign,
    Th,
    ThAlign,
    ThDir,
    ThScope,
    ThValign,
    Thead,
    TheadAlign,
    TheadDir,
    TheadValign,
    Tr,
    TrAlign,
    TrDir,
    TrValign,
    Tt,
    TtDir,
    Ul,
    UlDir,
    Var,
    VarDir,
)

__all__ = [
    "AbbreviatedLength",
    "AddresseeIdtype",
    "AddresseeIdentifier",
    "Affiliation",
    "AgentIdtype",
    "AgentIdentifier",
    "AgentName",
    "AgentRole",
    "AlternativeFormatEan13",
    "AlternativeFormatIsbn",
    "AlternativeProductEan13",
    "AlternativeProductIsbn",
    "Annotation",
    "AnnouncementDate",
    "Audience",
    "AudienceCode",
    "AudienceCodeType",
    "AudienceCodeTypeName",
    "AudienceCodeValue",
    "AudienceDescription",
    "AudienceRange",
    "AudienceRangePrecision",
    "AudienceRangeQualifier",
    "AudienceRangeValue",
    "AudienceRestrictionFlag",
    "AudienceRestrictionNote",
    "AvailabilityCode",
    "BasicmainSubject",
    "Basicversion",
    "BicdiscountGroupCode",
    "BicmainSubject",
    "Bicversion",
    "Barcode",
    "BatchBonus",
    "BatchQuantity",
    "Bible",
    "BibleContents",
    "BiblePurpose",
    "BibleReferenceLocation",
    "BibleTextFeature",
    "BibleTextOrganization",
    "BibleVersion",
    "BiographicalNote",
    "BookClubAdoption",
    "BookFormDetail",
    "Cbo",
    "CityOfPublication",
    "ClassOfTrade",
    "Complexity",
    "ComplexityCode",
    "ComplexitySchemeIdentifier",
    "ComponentNumber",
    "ComponentTypeName",
    "Conference",
    "ConferenceAcronym",
    "ConferenceDate",
    "ConferenceDescription",
    "ConferenceName",
    "ConferenceNumber",
    "ConferencePlace",
    "ConferenceRole",
    "ConferenceSponsor",
    "ConferenceSponsorIdtype",
    "ConferenceSponsorIdentifier",
    "ConferenceTheme",
    "ContainedItem",
    "ContentItem",
    "Contributor",
    "ContributorDescription",
    "ContributorRole",
    "ContributorStatement",
    "CopiesSold",
    "CopublisherName",
    "CopyrightOwner",
    "CopyrightOwnerIdtype",
    "CopyrightOwnerIdentifier",
    "CopyrightStatement",
    "CopyrightYear",
    "CorporateBodyAsSubject",
    "CorporateName",
    "CountryCode",
    "CountryExcluded",
    "CountryOfPublication",
    "CoverImageFormatCode",
    "CoverImageLink",
    "CoverImageLinkTypeCode",
    "CurrencyCode",
    "Doi",
    "Date",
    "DateFormat",
    "DefaultClassOfTrade",
    "DefaultCurrencyCode",
    "DefaultLanguageOfText",
    "DefaultLinearUnit",
    "DefaultPriceTypeCode",
    "DefaultWeightUnit",
    "DeletionCode",
    "DeletionText",
    "Dimensions",
    "DiscountCode",
    "DiscountCodeType",
    "DiscountCodeTypeName",
    "DiscountCoded",
    "DiscountPercent",
    "DistinctiveTitle",
    "DownloadCaption",
    "DownloadCopyrightNotice",
    "DownloadCredit",
    "DownloadTerms",
    "Ean13",
    "Ean13OfSet",
    "EditionNumber",
    "EditionStatement",
    "EditionTypeCode",
    "EditionVersionNumber",
    "EmailAddress",
    "EndDate",
    "EpubFormat",
    "EpubFormatDescription",
    "EpubFormatVersion",
    "EpubSource",
    "EpubSourceDescription",
    "EpubSourceVersion",
    "EpubType",
    "EpubTypeDescription",
    "EpubTypeNote",
    "EpubTypeVersion",
    "ExpectedDate",
    "ExpectedShipDate",
    "Extent",
    "ExtentType",
    "ExtentUnit",
    "ExtentValue",
    "FaxNumber",
    "FirstPageNumber",
    "FormerTitle",
    "FreeQuantity",
    "FromCompany",
    "FromEannumber",
    "FromEmail",
    "FromPerson",
    "FromSan",
    "Header",
    "Height",
    "IdtypeName",
    "Idvalue",
    "Isbn",
    "IsbnofSet",
    "Ismn",
    "IllustrationType",
    "IllustrationTypeDescription",
    "Illustrations",
    "IllustrationsNote",
    "ImageResolution",
    "Imprint",
    "ImprintName",
    "InitialPrintRun",
    "InterestAge",
    "IntermediaryAvailabilityCode",
    "ItemNumberWithinSet",
    "ItemQuantity",
    "KeyNames",
    "Language",
    "LanguageCode",
    "LanguageOfText",
    "LanguageRole",
    "LastDateForReturns",
    "LastPageNumber",
    "LettersAfterNames",
    "LevelSequenceNumber",
    "LocationIdtype",
    "LocationIdentifier",
    "LocationName",
    "MainDescription",
    "MainSeriesRecord",
    "MainSubject",
    "MainSubjectSchemeIdentifier",
    "MapScale",
    "MarketCountry",
    "MarketCountryExcluded",
    "MarketDate",
    "MarketDateRole",
    "MarketPublishingStatus",
    "MarketRepresentation",
    "MarketRestrictionDetail",
    "MarketTerritory",
    "Measure",
    "MeasureTypeCode",
    "MeasureUnitCode",
    "Measurement",
    "MediaFile",
    "MediaFileDate",
    "MediaFileFormatCode",
    "MediaFileLink",
    "MediaFileLinkTypeCode",
    "MediaFileTypeCode",
    "MessageNote",
    "MessageNumber",
    "MessageRepeat",
    "MinimumOrderQuantity",
    "Name",
    "NameCodeType",
    "NameCodeTypeName",
    "NameCodeValue",
    "NamesAfterKey",
    "NamesBeforeKey",
    "NewSupplier",
    "NoContributor",
    "NoEdition",
    "NoSeries",
    "NotForSale",
    "NotificationType",
    "Number",
    "NumberOfIllustrations",
    "NumberOfPages",
    "NumberOfPieces",
    "NumberWithinSeries",
    "Onixmessage",
    "OnHand",
    "OnOrder",
    "OnOrderDetail",
    "OnSaleDate",
    "OrderTime",
    "OriginalLanguage",
    "OriginalPublisher",
    "OtherText",
    "OutOfPrintDate",
    "PackQuantity",
    "PageRun",
    "PagesArabic",
    "PagesRoman",
    "ParentIdentifier",
    "Percent",
    "PersonAsSubject",
    "PersonDate",
    "PersonDateRole",
    "PersonName",
    "PersonNameIdtype",
    "PersonNameIdentifier",
    "PersonNameInverted",
    "PersonNameType",
    "PlaceAsSubject",
    "PrefixToKey",
    "Price",
    "PriceAmount",
    "PriceEffectiveFrom",
    "PriceEffectiveUntil",
    "PricePer",
    "PriceQualifier",
    "PriceStatus",
    "PriceTypeCode",
    "PriceTypeDescription",
    "Prize",
    "PrizeCode",
    "PrizeCountry",
    "PrizeJury",
    "PrizeName",
    "PrizeYear",
    "PrizesDescription",
    "Product",
    "ProductAvailability",
    "ProductClassification",
    "ProductClassificationCode",
    "ProductClassificationType",
    "ProductContentType",
    "ProductForm",
    "ProductFormDescription",
    "ProductFormDetail",
    "ProductFormFeature",
    "ProductFormFeatureDescription",
    "ProductFormFeatureType",
    "ProductFormFeatureValue",
    "ProductIdtype",
    "ProductIdentifier",
    "ProductPackaging",
    "ProductWebsite",
    "ProductWebsiteDescription",
    "ProductWebsiteLink",
    "ProfessionalAffiliation",
    "ProfessionalPosition",
    "PromotionCampaign",
    "PromotionContact",
    "PublicationDate",
    "Publisher",
    "PublisherName",
    "PublisherProductNo",
    "PublisherSeriesCode",
    "PublishingRole",
    "PublishingStatus",
    "PublishingStatusNote",
    "RecordReference",
    "RecordSourceIdentifier",
    "RecordSourceIdentifierType",
    "RecordSourceName",
    "RecordSourceType",
    "RegionCode",
    "Reissue",
    "ReissueDate",
    "ReissueDescription",
    "RelatedProduct",
    "RelationCode",
    "ReligiousText",
    "ReligiousTextFeature",
    "ReligiousTextFeatureCode",
    "ReligiousTextFeatureDescription",
    "ReligiousTextFeatureType",
    "ReligiousTextId",
    "ReplacedByEan13",
    "ReplacedByIsbn",
    "ReplacesEan13",
    "ReplacesIsbn",
    "ReprintDetail",
    "ReturnsCode",
    "ReturnsCodeType",
    "ReviewQuote",
    "RightsCountry",
    "RightsRegion",
    "RightsTerritory",
    "SalesOutlet",
    "SalesOutletIdtype",
    "SalesOutletIdentifier",
    "SalesOutletName",
    "SalesRestriction",
    "SalesRestrictionDetail",
    "SalesRestrictionType",
    "SalesRights",
    "SalesRightsType",
    "SenderIdtype",
    "SenderIdentifier",
    "SentDate",
    "SequenceNumber",
    "SequenceNumberWithinRole",
    "Series",
    "SeriesIdtype",
    "SeriesIssn",
    "SeriesIdentifier",
    "SeriesPartName",
    "Set",
    "SetItemTitle",
    "SetPartNumber",
    "SetPartTitle",
    "SponsorName",
    "StartDate",
    "Stock",
    "StockQuantityCode",
    "StockQuantityCodeType",
    "StockQuantityCodeTypeName",
    "StockQuantityCoded",
    "StudyBibleType",
    "SubSeriesRecord",
    "Subject",
    "SubjectCode",
    "SubjectHeadingText",
    "SubjectSchemeIdentifier",
    "SubjectSchemeName",
    "SubjectSchemeVersion",
    "SubordinateEntries",
    "Subtitle",
    "SuffixToKey",
    "SupplierEanlocationNumber",
    "SupplierIdtype",
    "SupplierIdentifier",
    "SupplierName",
    "SupplierRole",
    "SupplierSan",
    "SupplyDetail",
    "SupplyRestrictionDetail",
    "SupplyToCountry",
    "SupplyToCountryExcluded",
    "SupplyToRegion",
    "SupplyToTerritory",
    "TaxAmount1",
    "TaxAmount2",
    "TaxRateCode1",
    "TaxRateCode2",
    "TaxRatePercent1",
    "TaxRatePercent2",
    "TaxableAmount1",
    "TaxableAmount2",
    "TelephoneNumber",
    "Territory",
    "TerritoryExcluded",
    "Text",
    "TextAuthor",
    "TextCaseFlag",
    "TextFormat",
    "TextItem",
    "TextItemIdtype",
    "TextItemIdentifier",
    "TextItemType",
    "TextLink",
    "TextLinkType",
    "TextPublicationDate",
    "TextSourceCorporate",
    "TextSourceTitle",
    "TextTypeCode",
    "TextWithDownload",
    "ThesisPresentedTo",
    "ThesisType",
    "ThesisYear",
    "Thickness",
    "Title",
    "TitleOfSeries",
    "TitleOfSet",
    "TitlePrefix",
    "TitleText",
    "TitleType",
    "TitleWithoutPrefix",
    "TitlesAfterNames",
    "TitlesBeforeNames",
    "ToCompany",
    "ToEannumber",
    "ToPerson",
    "ToSan",
    "TradeAnnouncementDate",
    "TradeCategory",
    "TranslationOfTitle",
    "Upc",
    "UsschoolGrade",
    "UnnamedPersons",
    "UnpricedItemType",
    "Website",
    "WebsiteDescription",
    "WebsiteLink",
    "WebsiteRole",
    "Weight",
    "Width",
    "WorkIdtype",
    "WorkIdentifier",
    "YearFirstPublished",
    "YearOfAnnual",
    "List1",
    "List10",
    "List100",
    "List101",
    "List102",
    "List11",
    "List12",
    "List13",
    "List138",
    "List14",
    "List15",
    "List16",
    "List17",
    "List18",
    "List19",
    "List2",
    "List20",
    "List21",
    "List22",
    "List23",
    "List24",
    "List25",
    "List26",
    "List27",
    "List28",
    "List29",
    "List3",
    "List30",
    "List31",
    "List32",
    "List33",
    "List34",
    "List35",
    "List36",
    "List37",
    "List38",
    "List39",
    "List40",
    "List41",
    "List42",
    "List43",
    "List44",
    "List45",
    "List46",
    "List47",
    "List48",
    "List49",
    "List5",
    "List50",
    "List51",
    "List52",
    "List53",
    "List54",
    "List55",
    "List56",
    "List57",
    "List58",
    "List59",
    "List6",
    "List60",
    "List61",
    "List62",
    "List64",
    "List65",
    "List7",
    "List70",
    "List71",
    "List72",
    "List73",
    "List74",
    "List75",
    "List78",
    "List79",
    "List8",
    "List80",
    "List81",
    "List82",
    "List83",
    "List84",
    "List85",
    "List86",
    "List87",
    "List89",
    "List9",
    "List90",
    "List91",
    "List92",
    "List93",
    "List94",
    "List95",
    "List96",
    "List97",
    "A",
    "ADir",
    "AShape",
    "Abbr",
    "AbbrDir",
    "Acronym",
    "AcronymDir",
    "Address",
    "AddressDir",
    "Area",
    "AreaDir",
    "AreaNohref",
    "AreaShape",
    "B",
    "BDir",
    "Bdo",
    "BdoDir",
    "Big",
    "BigDir",
    "Blockquote",
    "BlockquoteDir",
    "Br",
    "Caption",
    "CaptionDir",
    "Cite",
    "CiteDir",
    "Code",
    "CodeDir",
    "Col",
    "ColAlign",
    "ColDir",
    "ColValign",
    "Colgroup",
    "ColgroupAlign",
    "ColgroupDir",
    "ColgroupValign",
    "Dd",
    "DdDir",
    "Dfn",
    "DfnDir",
    "Div",
    "DivDir",
    "Dl",
    "DlDir",
    "Dt",
    "DtDir",
    "Em",
    "EmDir",
    "H1",
    "H1Dir",
    "H2",
    "H2Dir",
    "H3",
    "H3Dir",
    "H4",
    "H4Dir",
    "H5",
    "H5Dir",
    "H6",
    "H6Dir",
    "Hr",
    "HrDir",
    "I",
    "IDir",
    "Img",
    "ImgDir",
    "ImgIsmap",
    "Kbd",
    "KbdDir",
    "Li",
    "LiDir",
    "Map",
    "MapDir",
    "Object",
    "ObjectDeclare",
    "ObjectDir",
    "Ol",
    "OlDir",
    "P",
    "PDir",
    "Param",
    "ParamValuetype",
    "Pre",
    "PreDir",
    "Q",
    "QDir",
    "Samp",
    "SampDir",
    "Small",
    "SmallDir",
    "Span",
    "SpanDir",
    "Strong",
    "StrongDir",
    "Sub",
    "SubDir",
    "Sup",
    "SupDir",
    "Table",
    "TableDir",
    "TableFrame",
    "TableRules",
    "Tbody",
    "TbodyAlign",
    "TbodyDir",
    "TbodyValign",
    "Td",
    "TdAlign",
    "TdDir",
    "TdScope",
    "TdValign",
    "Tfoot",
    "TfootAlign",
    "TfootDir",
    "TfootValign",
    "Th",
    "ThAlign",
    "ThDir",
    "ThScope",
    "ThValign",
    "Thead",
    "TheadAlign",
    "TheadDir",
    "TheadValign",
    "Tr",
    "TrAlign",
    "TrDir",
    "TrValign",
    "Tt",
    "TtDir",
    "Ul",
    "UlDir",
    "Var",
    "VarDir",
]
